"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 LiveKit, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
from . import handle_pb2
import sys
from . import track_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _VideoCodec:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoCodecEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoCodec.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VP8: _VideoCodec.ValueType  # 0
    H264: _VideoCodec.ValueType  # 1
    AV1: _VideoCodec.ValueType  # 2
    VP9: _VideoCodec.ValueType  # 3
    H265: _VideoCodec.ValueType  # 4

class VideoCodec(_VideoCodec, metaclass=_VideoCodecEnumTypeWrapper): ...

VP8: VideoCodec.ValueType  # 0
H264: VideoCodec.ValueType  # 1
AV1: VideoCodec.ValueType  # 2
VP9: VideoCodec.ValueType  # 3
H265: VideoCodec.ValueType  # 4
global___VideoCodec = VideoCodec

class _VideoRotation:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoRotationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoRotation.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VIDEO_ROTATION_0: _VideoRotation.ValueType  # 0
    VIDEO_ROTATION_90: _VideoRotation.ValueType  # 1
    VIDEO_ROTATION_180: _VideoRotation.ValueType  # 2
    VIDEO_ROTATION_270: _VideoRotation.ValueType  # 3

class VideoRotation(_VideoRotation, metaclass=_VideoRotationEnumTypeWrapper): ...

VIDEO_ROTATION_0: VideoRotation.ValueType  # 0
VIDEO_ROTATION_90: VideoRotation.ValueType  # 1
VIDEO_ROTATION_180: VideoRotation.ValueType  # 2
VIDEO_ROTATION_270: VideoRotation.ValueType  # 3
global___VideoRotation = VideoRotation

class _VideoBufferType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoBufferTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoBufferType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RGBA: _VideoBufferType.ValueType  # 0
    ABGR: _VideoBufferType.ValueType  # 1
    ARGB: _VideoBufferType.ValueType  # 2
    BGRA: _VideoBufferType.ValueType  # 3
    RGB24: _VideoBufferType.ValueType  # 4
    I420: _VideoBufferType.ValueType  # 5
    I420A: _VideoBufferType.ValueType  # 6
    I422: _VideoBufferType.ValueType  # 7
    I444: _VideoBufferType.ValueType  # 8
    I010: _VideoBufferType.ValueType  # 9
    NV12: _VideoBufferType.ValueType  # 10

class VideoBufferType(_VideoBufferType, metaclass=_VideoBufferTypeEnumTypeWrapper):
    """Values of this enum must not be changed
    It is used to serialize a rtc.VideoFrame on Python
    """

RGBA: VideoBufferType.ValueType  # 0
ABGR: VideoBufferType.ValueType  # 1
ARGB: VideoBufferType.ValueType  # 2
BGRA: VideoBufferType.ValueType  # 3
RGB24: VideoBufferType.ValueType  # 4
I420: VideoBufferType.ValueType  # 5
I420A: VideoBufferType.ValueType  # 6
I422: VideoBufferType.ValueType  # 7
I444: VideoBufferType.ValueType  # 8
I010: VideoBufferType.ValueType  # 9
NV12: VideoBufferType.ValueType  # 10
global___VideoBufferType = VideoBufferType

class _VideoStreamType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoStreamTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoStreamType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VIDEO_STREAM_NATIVE: _VideoStreamType.ValueType  # 0
    VIDEO_STREAM_WEBGL: _VideoStreamType.ValueType  # 1
    VIDEO_STREAM_HTML: _VideoStreamType.ValueType  # 2

class VideoStreamType(_VideoStreamType, metaclass=_VideoStreamTypeEnumTypeWrapper):
    """
    VideoStream
    """

VIDEO_STREAM_NATIVE: VideoStreamType.ValueType  # 0
VIDEO_STREAM_WEBGL: VideoStreamType.ValueType  # 1
VIDEO_STREAM_HTML: VideoStreamType.ValueType  # 2
global___VideoStreamType = VideoStreamType

class _VideoSourceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoSourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoSourceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VIDEO_SOURCE_NATIVE: _VideoSourceType.ValueType  # 0

class VideoSourceType(_VideoSourceType, metaclass=_VideoSourceTypeEnumTypeWrapper): ...

VIDEO_SOURCE_NATIVE: VideoSourceType.ValueType  # 0
global___VideoSourceType = VideoSourceType

@typing.final
class NewVideoStreamRequest(google.protobuf.message.Message):
    """Create a new VideoStream
    VideoStream is used to receive video frames from a track
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRACK_HANDLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    NORMALIZE_STRIDE_FIELD_NUMBER: builtins.int
    track_handle: builtins.int
    type: global___VideoStreamType.ValueType
    format: global___VideoBufferType.ValueType
    """Get the frame on a specific format"""
    normalize_stride: builtins.bool
    """if true, stride will be set to width/chroma_width"""
    def __init__(
        self,
        *,
        track_handle: builtins.int | None = ...,
        type: global___VideoStreamType.ValueType | None = ...,
        format: global___VideoBufferType.ValueType | None = ...,
        normalize_stride: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["format", b"format", "normalize_stride", b"normalize_stride", "track_handle", b"track_handle", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["format", b"format", "normalize_stride", b"normalize_stride", "track_handle", b"track_handle", "type", b"type"]) -> None: ...

global___NewVideoStreamRequest = NewVideoStreamRequest

@typing.final
class NewVideoStreamResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_FIELD_NUMBER: builtins.int
    @property
    def stream(self) -> global___OwnedVideoStream: ...
    def __init__(
        self,
        *,
        stream: global___OwnedVideoStream | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["stream", b"stream"]) -> None: ...

global___NewVideoStreamResponse = NewVideoStreamResponse

@typing.final
class VideoStreamFromParticipantRequest(google.protobuf.message.Message):
    """Request a video stream from a participant"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTICIPANT_HANDLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TRACK_SOURCE_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    NORMALIZE_STRIDE_FIELD_NUMBER: builtins.int
    participant_handle: builtins.int
    type: global___VideoStreamType.ValueType
    track_source: track_pb2.TrackSource.ValueType
    format: global___VideoBufferType.ValueType
    normalize_stride: builtins.bool
    def __init__(
        self,
        *,
        participant_handle: builtins.int | None = ...,
        type: global___VideoStreamType.ValueType | None = ...,
        track_source: track_pb2.TrackSource.ValueType | None = ...,
        format: global___VideoBufferType.ValueType | None = ...,
        normalize_stride: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["format", b"format", "normalize_stride", b"normalize_stride", "participant_handle", b"participant_handle", "track_source", b"track_source", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["format", b"format", "normalize_stride", b"normalize_stride", "participant_handle", b"participant_handle", "track_source", b"track_source", "type", b"type"]) -> None: ...

global___VideoStreamFromParticipantRequest = VideoStreamFromParticipantRequest

@typing.final
class VideoStreamFromParticipantResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_FIELD_NUMBER: builtins.int
    @property
    def stream(self) -> global___OwnedVideoStream: ...
    def __init__(
        self,
        *,
        stream: global___OwnedVideoStream | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["stream", b"stream"]) -> None: ...

global___VideoStreamFromParticipantResponse = VideoStreamFromParticipantResponse

@typing.final
class NewVideoSourceRequest(google.protobuf.message.Message):
    """Create a new VideoSource
    VideoSource is used to send video frame to a track
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    RESOLUTION_FIELD_NUMBER: builtins.int
    type: global___VideoSourceType.ValueType
    @property
    def resolution(self) -> global___VideoSourceResolution:
        """Used to determine which encodings to use + simulcast layers
        Most of the time it corresponds to the source resolution
        """

    def __init__(
        self,
        *,
        type: global___VideoSourceType.ValueType | None = ...,
        resolution: global___VideoSourceResolution | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resolution", b"resolution", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resolution", b"resolution", "type", b"type"]) -> None: ...

global___NewVideoSourceRequest = NewVideoSourceRequest

@typing.final
class NewVideoSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    @property
    def source(self) -> global___OwnedVideoSource: ...
    def __init__(
        self,
        *,
        source: global___OwnedVideoSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["source", b"source"]) -> None: ...

global___NewVideoSourceResponse = NewVideoSourceResponse

@typing.final
class CaptureVideoFrameRequest(google.protobuf.message.Message):
    """Push a frame to a VideoSource"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_HANDLE_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    TIMESTAMP_US_FIELD_NUMBER: builtins.int
    ROTATION_FIELD_NUMBER: builtins.int
    source_handle: builtins.int
    timestamp_us: builtins.int
    """In microseconds"""
    rotation: global___VideoRotation.ValueType
    @property
    def buffer(self) -> global___VideoBufferInfo: ...
    def __init__(
        self,
        *,
        source_handle: builtins.int | None = ...,
        buffer: global___VideoBufferInfo | None = ...,
        timestamp_us: builtins.int | None = ...,
        rotation: global___VideoRotation.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["buffer", b"buffer", "rotation", b"rotation", "source_handle", b"source_handle", "timestamp_us", b"timestamp_us"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "rotation", b"rotation", "source_handle", b"source_handle", "timestamp_us", b"timestamp_us"]) -> None: ...

global___CaptureVideoFrameRequest = CaptureVideoFrameRequest

@typing.final
class CaptureVideoFrameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CaptureVideoFrameResponse = CaptureVideoFrameResponse

@typing.final
class VideoConvertRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLIP_Y_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    DST_TYPE_FIELD_NUMBER: builtins.int
    flip_y: builtins.bool
    dst_type: global___VideoBufferType.ValueType
    @property
    def buffer(self) -> global___VideoBufferInfo: ...
    def __init__(
        self,
        *,
        flip_y: builtins.bool | None = ...,
        buffer: global___VideoBufferInfo | None = ...,
        dst_type: global___VideoBufferType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["buffer", b"buffer", "dst_type", b"dst_type", "flip_y", b"flip_y"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "dst_type", b"dst_type", "flip_y", b"flip_y"]) -> None: ...

global___VideoConvertRequest = VideoConvertRequest

@typing.final
class VideoConvertResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    error: builtins.str
    @property
    def buffer(self) -> global___OwnedVideoBuffer: ...
    def __init__(
        self,
        *,
        error: builtins.str | None = ...,
        buffer: global___OwnedVideoBuffer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["buffer", b"buffer", "error", b"error", "message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "error", b"error", "message", b"message"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["message", b"message"]) -> typing.Literal["error", "buffer"] | None: ...

global___VideoConvertResponse = VideoConvertResponse

@typing.final
class VideoResolution(google.protobuf.message.Message):
    """
    VideoFrame buffers
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    height: builtins.int
    frame_rate: builtins.float
    def __init__(
        self,
        *,
        width: builtins.int | None = ...,
        height: builtins.int | None = ...,
        frame_rate: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["frame_rate", b"frame_rate", "height", b"height", "width", b"width"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["frame_rate", b"frame_rate", "height", b"height", "width", b"width"]) -> None: ...

global___VideoResolution = VideoResolution

@typing.final
class VideoBufferInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ComponentInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATA_PTR_FIELD_NUMBER: builtins.int
        STRIDE_FIELD_NUMBER: builtins.int
        SIZE_FIELD_NUMBER: builtins.int
        data_ptr: builtins.int
        stride: builtins.int
        size: builtins.int
        def __init__(
            self,
            *,
            data_ptr: builtins.int | None = ...,
            stride: builtins.int | None = ...,
            size: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["data_ptr", b"data_ptr", "size", b"size", "stride", b"stride"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["data_ptr", b"data_ptr", "size", b"size", "stride", b"stride"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    DATA_PTR_FIELD_NUMBER: builtins.int
    STRIDE_FIELD_NUMBER: builtins.int
    COMPONENTS_FIELD_NUMBER: builtins.int
    type: global___VideoBufferType.ValueType
    width: builtins.int
    height: builtins.int
    data_ptr: builtins.int
    stride: builtins.int
    """only for packed formats"""
    @property
    def components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBufferInfo.ComponentInfo]: ...
    def __init__(
        self,
        *,
        type: global___VideoBufferType.ValueType | None = ...,
        width: builtins.int | None = ...,
        height: builtins.int | None = ...,
        data_ptr: builtins.int | None = ...,
        stride: builtins.int | None = ...,
        components: collections.abc.Iterable[global___VideoBufferInfo.ComponentInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_ptr", b"data_ptr", "height", b"height", "stride", b"stride", "type", b"type", "width", b"width"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["components", b"components", "data_ptr", b"data_ptr", "height", b"height", "stride", b"stride", "type", b"type", "width", b"width"]) -> None: ...

global___VideoBufferInfo = VideoBufferInfo

@typing.final
class OwnedVideoBuffer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLE_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    @property
    def handle(self) -> handle_pb2.FfiOwnedHandle: ...
    @property
    def info(self) -> global___VideoBufferInfo: ...
    def __init__(
        self,
        *,
        handle: handle_pb2.FfiOwnedHandle | None = ...,
        info: global___VideoBufferInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handle", b"handle", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle", "info", b"info"]) -> None: ...

global___OwnedVideoBuffer = OwnedVideoBuffer

@typing.final
class VideoStreamInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: global___VideoStreamType.ValueType
    def __init__(
        self,
        *,
        type: global___VideoStreamType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

global___VideoStreamInfo = VideoStreamInfo

@typing.final
class OwnedVideoStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLE_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    @property
    def handle(self) -> handle_pb2.FfiOwnedHandle: ...
    @property
    def info(self) -> global___VideoStreamInfo: ...
    def __init__(
        self,
        *,
        handle: handle_pb2.FfiOwnedHandle | None = ...,
        info: global___VideoStreamInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handle", b"handle", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle", "info", b"info"]) -> None: ...

global___OwnedVideoStream = OwnedVideoStream

@typing.final
class VideoStreamEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_HANDLE_FIELD_NUMBER: builtins.int
    FRAME_RECEIVED_FIELD_NUMBER: builtins.int
    EOS_FIELD_NUMBER: builtins.int
    stream_handle: builtins.int
    @property
    def frame_received(self) -> global___VideoFrameReceived: ...
    @property
    def eos(self) -> global___VideoStreamEOS: ...
    def __init__(
        self,
        *,
        stream_handle: builtins.int | None = ...,
        frame_received: global___VideoFrameReceived | None = ...,
        eos: global___VideoStreamEOS | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["eos", b"eos", "frame_received", b"frame_received", "message", b"message", "stream_handle", b"stream_handle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["eos", b"eos", "frame_received", b"frame_received", "message", b"message", "stream_handle", b"stream_handle"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["message", b"message"]) -> typing.Literal["frame_received", "eos"] | None: ...

global___VideoStreamEvent = VideoStreamEvent

@typing.final
class VideoFrameReceived(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUFFER_FIELD_NUMBER: builtins.int
    TIMESTAMP_US_FIELD_NUMBER: builtins.int
    ROTATION_FIELD_NUMBER: builtins.int
    timestamp_us: builtins.int
    """In microseconds"""
    rotation: global___VideoRotation.ValueType
    @property
    def buffer(self) -> global___OwnedVideoBuffer: ...
    def __init__(
        self,
        *,
        buffer: global___OwnedVideoBuffer | None = ...,
        timestamp_us: builtins.int | None = ...,
        rotation: global___VideoRotation.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["buffer", b"buffer", "rotation", b"rotation", "timestamp_us", b"timestamp_us"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "rotation", b"rotation", "timestamp_us", b"timestamp_us"]) -> None: ...

global___VideoFrameReceived = VideoFrameReceived

@typing.final
class VideoStreamEOS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoStreamEOS = VideoStreamEOS

@typing.final
class VideoSourceResolution(google.protobuf.message.Message):
    """
    VideoSource
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    width: builtins.int
    height: builtins.int
    def __init__(
        self,
        *,
        width: builtins.int | None = ...,
        height: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["height", b"height", "width", b"width"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["height", b"height", "width", b"width"]) -> None: ...

global___VideoSourceResolution = VideoSourceResolution

@typing.final
class VideoSourceInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: global___VideoSourceType.ValueType
    def __init__(
        self,
        *,
        type: global___VideoSourceType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

global___VideoSourceInfo = VideoSourceInfo

@typing.final
class OwnedVideoSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLE_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    @property
    def handle(self) -> handle_pb2.FfiOwnedHandle: ...
    @property
    def info(self) -> global___VideoSourceInfo: ...
    def __init__(
        self,
        *,
        handle: handle_pb2.FfiOwnedHandle | None = ...,
        info: global___VideoSourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handle", b"handle", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle", "info", b"info"]) -> None: ...

global___OwnedVideoSource = OwnedVideoSource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: room.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import e2ee_pb2 as e2ee__pb2
from . import handle_pb2 as handle__pb2
from . import participant_pb2 as participant__pb2
from . import track_pb2 as track__pb2
from . import video_frame_pb2 as video__frame__pb2
from . import stats_pb2 as stats__pb2
from . import data_stream_pb2 as data__stream__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nroom.proto\x12\rlivekit.proto\x1a\ne2ee.proto\x1a\x0chandle.proto\x1a\x11participant.proto\x1a\x0btrack.proto\x1a\x11video_frame.proto\x1a\x0bstats.proto\x1a\x11\x64\x61ta_stream.proto\"Y\n\x0e\x43onnectRequest\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\r\n\x05token\x18\x02 \x02(\t\x12+\n\x07options\x18\x03 \x02(\x0b\x32\x1a.livekit.proto.RoomOptions\"#\n\x0f\x43onnectResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"\xbf\x03\n\x0f\x43onnectCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32%.livekit.proto.ConnectCallback.ResultH\x00\x1a\x89\x01\n\x15ParticipantWithTracks\x12\x34\n\x0bparticipant\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedParticipant\x12:\n\x0cpublications\x18\x02 \x03(\x0b\x32$.livekit.proto.OwnedTrackPublication\x1a\xb8\x01\n\x06Result\x12&\n\x04room\x18\x01 \x02(\x0b\x32\x18.livekit.proto.OwnedRoom\x12:\n\x11local_participant\x18\x02 \x02(\x0b\x32\x1f.livekit.proto.OwnedParticipant\x12J\n\x0cparticipants\x18\x03 \x03(\x0b\x32\x34.livekit.proto.ConnectCallback.ParticipantWithTracksB\t\n\x07message\"(\n\x11\x44isconnectRequest\x12\x13\n\x0broom_handle\x18\x01 \x02(\x04\"&\n\x12\x44isconnectResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"&\n\x12\x44isconnectCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"\x82\x01\n\x13PublishTrackRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x14\n\x0ctrack_handle\x18\x02 \x02(\x04\x12\x33\n\x07options\x18\x03 \x02(\x0b\x32\".livekit.proto.TrackPublishOptions\"(\n\x14PublishTrackResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"\x81\x01\n\x14PublishTrackCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12;\n\x0bpublication\x18\x03 \x01(\x0b\x32$.livekit.proto.OwnedTrackPublicationH\x00\x42\t\n\x07message\"g\n\x15UnpublishTrackRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x11\n\ttrack_sid\x18\x02 \x02(\t\x12\x19\n\x11stop_on_unpublish\x18\x03 \x02(\x08\"*\n\x16UnpublishTrackResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"9\n\x16UnpublishTrackCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xb9\x01\n\x12PublishDataRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x10\n\x08\x64\x61ta_ptr\x18\x02 \x02(\x04\x12\x10\n\x08\x64\x61ta_len\x18\x03 \x02(\x04\x12\x10\n\x08reliable\x18\x04 \x02(\x08\x12\x1c\n\x10\x64\x65stination_sids\x18\x05 \x03(\tB\x02\x18\x01\x12\r\n\x05topic\x18\x06 \x01(\t\x12\x1e\n\x16\x64\x65stination_identities\x18\x07 \x03(\t\"\'\n\x13PublishDataResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"6\n\x13PublishDataCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xa6\x01\n\x1bPublishTranscriptionRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x1c\n\x14participant_identity\x18\x02 \x02(\t\x12\x10\n\x08track_id\x18\x03 \x02(\t\x12\x35\n\x08segments\x18\x04 \x03(\x0b\x32#.livekit.proto.TranscriptionSegment\"0\n\x1cPublishTranscriptionResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"?\n\x1cPublishTranscriptionCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"v\n\x15PublishSipDtmfRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x0c\n\x04\x63ode\x18\x02 \x02(\r\x12\r\n\x05\x64igit\x18\x03 \x02(\t\x12\x1e\n\x16\x64\x65stination_identities\x18\x04 \x03(\t\"*\n\x16PublishSipDtmfResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"9\n\x16PublishSipDtmfCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"M\n\x17SetLocalMetadataRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x10\n\x08metadata\x18\x02 \x02(\t\",\n\x18SetLocalMetadataResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\";\n\x18SetLocalMetadataCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\x84\x01\n\x16SendChatMessageRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x0f\n\x07message\x18\x02 \x02(\t\x12\x1e\n\x16\x64\x65stination_identities\x18\x03 \x03(\t\x12\x17\n\x0fsender_identity\x18\x04 \x01(\t\"\xbc\x01\n\x16\x45\x64itChatMessageRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x11\n\tedit_text\x18\x02 \x02(\t\x12\x34\n\x10original_message\x18\x03 \x02(\x0b\x32\x1a.livekit.proto.ChatMessage\x12\x1e\n\x16\x64\x65stination_identities\x18\x04 \x03(\t\x12\x17\n\x0fsender_identity\x18\x05 \x01(\t\"+\n\x17SendChatMessageResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"{\n\x17SendChatMessageCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12\x32\n\x0c\x63hat_message\x18\x03 \x01(\x0b\x32\x1a.livekit.proto.ChatMessageH\x00\x42\t\n\x07message\"q\n\x19SetLocalAttributesRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x32\n\nattributes\x18\x02 \x03(\x0b\x32\x1e.livekit.proto.AttributesEntry\"-\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\".\n\x1aSetLocalAttributesResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"=\n\x1aSetLocalAttributesCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"E\n\x13SetLocalNameRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x0c\n\x04name\x18\x02 \x02(\t\"(\n\x14SetLocalNameResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"7\n\x14SetLocalNameCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"E\n\x14SetSubscribedRequest\x12\x11\n\tsubscribe\x18\x01 \x02(\x08\x12\x1a\n\x12publication_handle\x18\x02 \x02(\x04\"\x17\n\x15SetSubscribedResponse\"-\n\x16GetSessionStatsRequest\x12\x13\n\x0broom_handle\x18\x01 \x02(\x04\"+\n\x17GetSessionStatsResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"\xf7\x01\n\x17GetSessionStatsCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12?\n\x06result\x18\x03 \x01(\x0b\x32-.livekit.proto.GetSessionStatsCallback.ResultH\x00\x1am\n\x06Result\x12\x30\n\x0fpublisher_stats\x18\x01 \x03(\x0b\x32\x17.livekit.proto.RtcStats\x12\x31\n\x10subscriber_stats\x18\x02 \x03(\x0b\x32\x17.livekit.proto.RtcStatsB\t\n\x07message\";\n\rVideoEncoding\x12\x13\n\x0bmax_bitrate\x18\x01 \x02(\x04\x12\x15\n\rmax_framerate\x18\x02 \x02(\x01\"$\n\rAudioEncoding\x12\x13\n\x0bmax_bitrate\x18\x01 \x02(\x04\"\xb5\x02\n\x13TrackPublishOptions\x12\x34\n\x0evideo_encoding\x18\x01 \x01(\x0b\x32\x1c.livekit.proto.VideoEncoding\x12\x34\n\x0e\x61udio_encoding\x18\x02 \x01(\x0b\x32\x1c.livekit.proto.AudioEncoding\x12.\n\x0bvideo_codec\x18\x03 \x01(\x0e\x32\x19.livekit.proto.VideoCodec\x12\x0b\n\x03\x64tx\x18\x04 \x01(\x08\x12\x0b\n\x03red\x18\x05 \x01(\x08\x12\x11\n\tsimulcast\x18\x06 \x01(\x08\x12*\n\x06source\x18\x07 \x01(\x0e\x32\x1a.livekit.proto.TrackSource\x12\x0e\n\x06stream\x18\x08 \x01(\t\x12\x19\n\x11preconnect_buffer\x18\t \x01(\x08\"=\n\tIceServer\x12\x0c\n\x04urls\x18\x01 \x03(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xc4\x01\n\tRtcConfig\x12;\n\x12ice_transport_type\x18\x01 \x01(\x0e\x32\x1f.livekit.proto.IceTransportType\x12K\n\x1a\x63ontinual_gathering_policy\x18\x02 \x01(\x0e\x32\'.livekit.proto.ContinualGatheringPolicy\x12-\n\x0bice_servers\x18\x03 \x03(\x0b\x32\x18.livekit.proto.IceServer\"\xf2\x01\n\x0bRoomOptions\x12\x16\n\x0e\x61uto_subscribe\x18\x01 \x01(\x08\x12\x17\n\x0f\x61\x64\x61ptive_stream\x18\x02 \x01(\x08\x12\x10\n\x08\x64ynacast\x18\x03 \x01(\x08\x12,\n\x04\x65\x32\x65\x65\x18\x04 \x01(\x0b\x32\x1a.livekit.proto.E2eeOptionsB\x02\x18\x01\x12,\n\nrtc_config\x18\x05 \x01(\x0b\x32\x18.livekit.proto.RtcConfig\x12\x14\n\x0cjoin_retries\x18\x06 \x01(\r\x12.\n\nencryption\x18\x07 \x01(\x0b\x32\x1a.livekit.proto.E2eeOptions\"w\n\x14TranscriptionSegment\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0c\n\x04text\x18\x02 \x02(\t\x12\x12\n\nstart_time\x18\x03 \x02(\x04\x12\x10\n\x08\x65nd_time\x18\x04 \x02(\x04\x12\r\n\x05\x66inal\x18\x05 \x02(\x08\x12\x10\n\x08language\x18\x06 \x02(\t\"0\n\nBufferInfo\x12\x10\n\x08\x64\x61ta_ptr\x18\x01 \x02(\x04\x12\x10\n\x08\x64\x61ta_len\x18\x02 \x02(\x04\"e\n\x0bOwnedBuffer\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12\'\n\x04\x64\x61ta\x18\x02 \x02(\x0b\x32\x19.livekit.proto.BufferInfo\"\xaa\x14\n\tRoomEvent\x12\x13\n\x0broom_handle\x18\x01 \x02(\x04\x12\x44\n\x15participant_connected\x18\x02 \x01(\x0b\x32#.livekit.proto.ParticipantConnectedH\x00\x12J\n\x18participant_disconnected\x18\x03 \x01(\x0b\x32&.livekit.proto.ParticipantDisconnectedH\x00\x12\x43\n\x15local_track_published\x18\x04 \x01(\x0b\x32\".livekit.proto.LocalTrackPublishedH\x00\x12G\n\x17local_track_unpublished\x18\x05 \x01(\x0b\x32$.livekit.proto.LocalTrackUnpublishedH\x00\x12\x45\n\x16local_track_subscribed\x18\x06 \x01(\x0b\x32#.livekit.proto.LocalTrackSubscribedH\x00\x12\x38\n\x0ftrack_published\x18\x07 \x01(\x0b\x32\x1d.livekit.proto.TrackPublishedH\x00\x12<\n\x11track_unpublished\x18\x08 \x01(\x0b\x32\x1f.livekit.proto.TrackUnpublishedH\x00\x12:\n\x10track_subscribed\x18\t \x01(\x0b\x32\x1e.livekit.proto.TrackSubscribedH\x00\x12>\n\x12track_unsubscribed\x18\n \x01(\x0b\x32 .livekit.proto.TrackUnsubscribedH\x00\x12K\n\x19track_subscription_failed\x18\x0b \x01(\x0b\x32&.livekit.proto.TrackSubscriptionFailedH\x00\x12\x30\n\x0btrack_muted\x18\x0c \x01(\x0b\x32\x19.livekit.proto.TrackMutedH\x00\x12\x34\n\rtrack_unmuted\x18\r \x01(\x0b\x32\x1b.livekit.proto.TrackUnmutedH\x00\x12G\n\x17\x61\x63tive_speakers_changed\x18\x0e \x01(\x0b\x32$.livekit.proto.ActiveSpeakersChangedH\x00\x12\x43\n\x15room_metadata_changed\x18\x0f \x01(\x0b\x32\".livekit.proto.RoomMetadataChangedH\x00\x12\x39\n\x10room_sid_changed\x18\x10 \x01(\x0b\x32\x1d.livekit.proto.RoomSidChangedH\x00\x12Q\n\x1cparticipant_metadata_changed\x18\x11 \x01(\x0b\x32).livekit.proto.ParticipantMetadataChangedH\x00\x12I\n\x18participant_name_changed\x18\x12 \x01(\x0b\x32%.livekit.proto.ParticipantNameChangedH\x00\x12U\n\x1eparticipant_attributes_changed\x18\x13 \x01(\x0b\x32+.livekit.proto.ParticipantAttributesChangedH\x00\x12\x62\n%participant_encryption_status_changed\x18\' \x01(\x0b\x32\x31.livekit.proto.ParticipantEncryptionStatusChangedH\x00\x12M\n\x1a\x63onnection_quality_changed\x18\x14 \x01(\x0b\x32\'.livekit.proto.ConnectionQualityChangedH\x00\x12I\n\x18\x63onnection_state_changed\x18\x15 \x01(\x0b\x32%.livekit.proto.ConnectionStateChangedH\x00\x12\x33\n\x0c\x64isconnected\x18\x16 \x01(\x0b\x32\x1b.livekit.proto.DisconnectedH\x00\x12\x33\n\x0creconnecting\x18\x17 \x01(\x0b\x32\x1b.livekit.proto.ReconnectingH\x00\x12\x31\n\x0breconnected\x18\x18 \x01(\x0b\x32\x1a.livekit.proto.ReconnectedH\x00\x12=\n\x12\x65\x32\x65\x65_state_changed\x18\x19 \x01(\x0b\x32\x1f.livekit.proto.E2eeStateChangedH\x00\x12%\n\x03\x65os\x18\x1a \x01(\x0b\x32\x16.livekit.proto.RoomEOSH\x00\x12\x41\n\x14\x64\x61ta_packet_received\x18\x1b \x01(\x0b\x32!.livekit.proto.DataPacketReceivedH\x00\x12\x46\n\x16transcription_received\x18\x1c \x01(\x0b\x32$.livekit.proto.TranscriptionReceivedH\x00\x12:\n\x0c\x63hat_message\x18\x1d \x01(\x0b\x32\".livekit.proto.ChatMessageReceivedH\x00\x12I\n\x16stream_header_received\x18\x1e \x01(\x0b\x32\'.livekit.proto.DataStreamHeaderReceivedH\x00\x12G\n\x15stream_chunk_received\x18\x1f \x01(\x0b\x32&.livekit.proto.DataStreamChunkReceivedH\x00\x12K\n\x17stream_trailer_received\x18  \x01(\x0b\x32(.livekit.proto.DataStreamTrailerReceivedH\x00\x12i\n\"data_channel_low_threshold_changed\x18! \x01(\x0b\x32;.livekit.proto.DataChannelBufferedAmountLowThresholdChangedH\x00\x12=\n\x12\x62yte_stream_opened\x18\" \x01(\x0b\x32\x1f.livekit.proto.ByteStreamOpenedH\x00\x12=\n\x12text_stream_opened\x18# \x01(\x0b\x32\x1f.livekit.proto.TextStreamOpenedH\x00\x12/\n\x0croom_updated\x18$ \x01(\x0b\x32\x17.livekit.proto.RoomInfoH\x00\x12(\n\x05moved\x18% \x01(\x0b\x32\x17.livekit.proto.RoomInfoH\x00\x12\x42\n\x14participants_updated\x18& \x01(\x0b\x32\".livekit.proto.ParticipantsUpdatedH\x00\x42\t\n\x07message\"\xc9\x02\n\x08RoomInfo\x12\x0b\n\x03sid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x02(\t\x12\x10\n\x08metadata\x18\x03 \x02(\t\x12.\n&lossy_dc_buffered_amount_low_threshold\x18\x04 \x02(\x04\x12\x31\n)reliable_dc_buffered_amount_low_threshold\x18\x05 \x02(\x04\x12\x15\n\rempty_timeout\x18\x06 \x02(\r\x12\x19\n\x11\x64\x65parture_timeout\x18\x07 \x02(\r\x12\x18\n\x10max_participants\x18\x08 \x02(\r\x12\x15\n\rcreation_time\x18\t \x02(\x03\x12\x18\n\x10num_participants\x18\n \x02(\r\x12\x16\n\x0enum_publishers\x18\x0b \x02(\r\x12\x18\n\x10\x61\x63tive_recording\x18\x0c \x02(\x08\"a\n\tOwnedRoom\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12%\n\x04info\x18\x02 \x02(\x0b\x32\x17.livekit.proto.RoomInfo\"K\n\x13ParticipantsUpdated\x12\x34\n\x0cparticipants\x18\x01 \x03(\x0b\x32\x1e.livekit.proto.ParticipantInfo\"E\n\x14ParticipantConnected\x12-\n\x04info\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedParticipant\"s\n\x17ParticipantDisconnected\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12:\n\x11\x64isconnect_reason\x18\x02 \x02(\x0e\x32\x1f.livekit.proto.DisconnectReason\"(\n\x13LocalTrackPublished\x12\x11\n\ttrack_sid\x18\x01 \x02(\t\"0\n\x15LocalTrackUnpublished\x12\x17\n\x0fpublication_sid\x18\x01 \x02(\t\")\n\x14LocalTrackSubscribed\x12\x11\n\ttrack_sid\x18\x02 \x02(\t\"i\n\x0eTrackPublished\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x39\n\x0bpublication\x18\x02 \x02(\x0b\x32$.livekit.proto.OwnedTrackPublication\"I\n\x10TrackUnpublished\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x17\n\x0fpublication_sid\x18\x02 \x02(\t\"Y\n\x0fTrackSubscribed\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12(\n\x05track\x18\x02 \x02(\x0b\x32\x19.livekit.proto.OwnedTrack\"D\n\x11TrackUnsubscribed\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x11\n\ttrack_sid\x18\x02 \x02(\t\"Y\n\x17TrackSubscriptionFailed\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x11\n\ttrack_sid\x18\x02 \x02(\t\x12\r\n\x05\x65rror\x18\x03 \x02(\t\"=\n\nTrackMuted\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x11\n\ttrack_sid\x18\x02 \x02(\t\"?\n\x0cTrackUnmuted\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x11\n\ttrack_sid\x18\x02 \x02(\t\"_\n\x10\x45\x32\x65\x65StateChanged\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12-\n\x05state\x18\x02 \x02(\x0e\x32\x1e.livekit.proto.EncryptionState\"7\n\x15\x41\x63tiveSpeakersChanged\x12\x1e\n\x16participant_identities\x18\x01 \x03(\t\"\'\n\x13RoomMetadataChanged\x12\x10\n\x08metadata\x18\x01 \x02(\t\"\x1d\n\x0eRoomSidChanged\x12\x0b\n\x03sid\x18\x01 \x02(\t\"L\n\x1aParticipantMetadataChanged\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x02(\t\"\xac\x01\n\x1cParticipantAttributesChanged\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x32\n\nattributes\x18\x02 \x03(\x0b\x32\x1e.livekit.proto.AttributesEntry\x12:\n\x12\x63hanged_attributes\x18\x03 \x03(\x0b\x32\x1e.livekit.proto.AttributesEntry\"X\n\"ParticipantEncryptionStatusChanged\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x14\n\x0cis_encrypted\x18\x02 \x02(\x08\"D\n\x16ParticipantNameChanged\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x0c\n\x04name\x18\x02 \x02(\t\"k\n\x18\x43onnectionQualityChanged\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x31\n\x07quality\x18\x02 \x02(\x0e\x32 .livekit.proto.ConnectionQuality\"E\n\nUserPacket\x12(\n\x04\x64\x61ta\x18\x01 \x02(\x0b\x32\x1a.livekit.proto.OwnedBuffer\x12\r\n\x05topic\x18\x02 \x01(\t\"y\n\x0b\x43hatMessage\x12\n\n\x02id\x18\x01 \x02(\t\x12\x11\n\ttimestamp\x18\x02 \x02(\x03\x12\x0f\n\x07message\x18\x03 \x02(\t\x12\x16\n\x0e\x65\x64it_timestamp\x18\x04 \x01(\x03\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08\x12\x11\n\tgenerated\x18\x06 \x01(\x08\"`\n\x13\x43hatMessageReceived\x12+\n\x07message\x18\x01 \x02(\x0b\x32\x1a.livekit.proto.ChatMessage\x12\x1c\n\x14participant_identity\x18\x02 \x02(\t\"&\n\x07SipDTMF\x12\x0c\n\x04\x63ode\x18\x01 \x02(\r\x12\r\n\x05\x64igit\x18\x02 \x01(\t\"\xbf\x01\n\x12\x44\x61taPacketReceived\x12+\n\x04kind\x18\x01 \x02(\x0e\x32\x1d.livekit.proto.DataPacketKind\x12\x1c\n\x14participant_identity\x18\x02 \x02(\t\x12)\n\x04user\x18\x04 \x01(\x0b\x32\x19.livekit.proto.UserPacketH\x00\x12*\n\x08sip_dtmf\x18\x05 \x01(\x0b\x32\x16.livekit.proto.SipDTMFH\x00\x42\x07\n\x05value\"\x7f\n\x15TranscriptionReceived\x12\x1c\n\x14participant_identity\x18\x01 \x01(\t\x12\x11\n\ttrack_sid\x18\x02 \x01(\t\x12\x35\n\x08segments\x18\x03 \x03(\x0b\x32#.livekit.proto.TranscriptionSegment\"G\n\x16\x43onnectionStateChanged\x12-\n\x05state\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.ConnectionState\"\x0b\n\tConnected\"?\n\x0c\x44isconnected\x12/\n\x06reason\x18\x01 \x02(\x0e\x32\x1f.livekit.proto.DisconnectReason\"\x0e\n\x0cReconnecting\"\r\n\x0bReconnected\"\t\n\x07RoomEOS\"\x8e\x07\n\nDataStream\x1a\xaa\x01\n\nTextHeader\x12?\n\x0eoperation_type\x18\x01 \x02(\x0e\x32\'.livekit.proto.DataStream.OperationType\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x1a\n\x12reply_to_stream_id\x18\x03 \x01(\t\x12\x1b\n\x13\x61ttached_stream_ids\x18\x04 \x03(\t\x12\x11\n\tgenerated\x18\x05 \x01(\x08\x1a\x1a\n\nByteHeader\x12\x0c\n\x04name\x18\x01 \x02(\t\x1a\xeb\x02\n\x06Header\x12\x11\n\tstream_id\x18\x01 \x02(\t\x12\x11\n\ttimestamp\x18\x02 \x02(\x03\x12\x11\n\tmime_type\x18\x03 \x02(\t\x12\r\n\x05topic\x18\x04 \x02(\t\x12\x14\n\x0ctotal_length\x18\x05 \x01(\x04\x12\x44\n\nattributes\x18\x06 \x03(\x0b\x32\x30.livekit.proto.DataStream.Header.AttributesEntry\x12;\n\x0btext_header\x18\x07 \x01(\x0b\x32$.livekit.proto.DataStream.TextHeaderH\x00\x12;\n\x0b\x62yte_header\x18\x08 \x01(\x0b\x32$.livekit.proto.DataStream.ByteHeaderH\x00\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0e\x63ontent_header\x1a]\n\x05\x43hunk\x12\x11\n\tstream_id\x18\x01 \x02(\t\x12\x13\n\x0b\x63hunk_index\x18\x02 \x02(\x04\x12\x0f\n\x07\x63ontent\x18\x03 \x02(\x0c\x12\x0f\n\x07version\x18\x04 \x01(\x05\x12\n\n\x02iv\x18\x05 \x01(\x0c\x1a\xa6\x01\n\x07Trailer\x12\x11\n\tstream_id\x18\x01 \x02(\t\x12\x0e\n\x06reason\x18\x02 \x02(\t\x12\x45\n\nattributes\x18\x03 \x03(\x0b\x32\x31.livekit.proto.DataStream.Trailer.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\rOperationType\x12\n\n\x06\x43REATE\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x12\x0c\n\x08REACTION\x10\x03\"j\n\x18\x44\x61taStreamHeaderReceived\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x30\n\x06header\x18\x02 \x02(\x0b\x32 .livekit.proto.DataStream.Header\"g\n\x17\x44\x61taStreamChunkReceived\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12.\n\x05\x63hunk\x18\x02 \x02(\x0b\x32\x1f.livekit.proto.DataStream.Chunk\"m\n\x19\x44\x61taStreamTrailerReceived\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x32\n\x07trailer\x18\x02 \x02(\x0b\x32!.livekit.proto.DataStream.Trailer\"\xa6\x01\n\x17SendStreamHeaderRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x30\n\x06header\x18\x02 \x02(\x0b\x32 .livekit.proto.DataStream.Header\x12\x1e\n\x16\x64\x65stination_identities\x18\x03 \x03(\t\x12\x17\n\x0fsender_identity\x18\x04 \x02(\t\"\xa3\x01\n\x16SendStreamChunkRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12.\n\x05\x63hunk\x18\x02 \x02(\x0b\x32\x1f.livekit.proto.DataStream.Chunk\x12\x1e\n\x16\x64\x65stination_identities\x18\x03 \x03(\t\x12\x17\n\x0fsender_identity\x18\x04 \x02(\t\"\xa9\x01\n\x18SendStreamTrailerRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x32\n\x07trailer\x18\x02 \x02(\x0b\x32!.livekit.proto.DataStream.Trailer\x12\x1e\n\x16\x64\x65stination_identities\x18\x03 \x03(\t\x12\x17\n\x0fsender_identity\x18\x04 \x02(\t\",\n\x18SendStreamHeaderResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"+\n\x17SendStreamChunkResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"-\n\x19SendStreamTrailerResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\";\n\x18SendStreamHeaderCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\":\n\x17SendStreamChunkCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"<\n\x19SendStreamTrailerCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\x93\x01\n/SetDataChannelBufferedAmountLowThresholdRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12\x11\n\tthreshold\x18\x02 \x02(\x04\x12+\n\x04kind\x18\x03 \x02(\x0e\x32\x1d.livekit.proto.DataPacketKind\"2\n0SetDataChannelBufferedAmountLowThresholdResponse\"n\n,DataChannelBufferedAmountLowThresholdChanged\x12+\n\x04kind\x18\x01 \x02(\x0e\x32\x1d.livekit.proto.DataPacketKind\x12\x11\n\tthreshold\x18\x02 \x02(\x04\"f\n\x10\x42yteStreamOpened\x12\x34\n\x06reader\x18\x01 \x02(\x0b\x32$.livekit.proto.OwnedByteStreamReader\x12\x1c\n\x14participant_identity\x18\x02 \x02(\t\"f\n\x10TextStreamOpened\x12\x34\n\x06reader\x18\x01 \x02(\x0b\x32$.livekit.proto.OwnedTextStreamReader\x12\x1c\n\x14participant_identity\x18\x02 \x02(\t*P\n\x10IceTransportType\x12\x13\n\x0fTRANSPORT_RELAY\x10\x00\x12\x14\n\x10TRANSPORT_NOHOST\x10\x01\x12\x11\n\rTRANSPORT_ALL\x10\x02*C\n\x18\x43ontinualGatheringPolicy\x12\x0f\n\x0bGATHER_ONCE\x10\x00\x12\x16\n\x12GATHER_CONTINUALLY\x10\x01*`\n\x11\x43onnectionQuality\x12\x10\n\x0cQUALITY_POOR\x10\x00\x12\x10\n\x0cQUALITY_GOOD\x10\x01\x12\x15\n\x11QUALITY_EXCELLENT\x10\x02\x12\x10\n\x0cQUALITY_LOST\x10\x03*S\n\x0f\x43onnectionState\x12\x15\n\x11\x43ONN_DISCONNECTED\x10\x00\x12\x12\n\x0e\x43ONN_CONNECTED\x10\x01\x12\x15\n\x11\x43ONN_RECONNECTING\x10\x02*3\n\x0e\x44\x61taPacketKind\x12\x0e\n\nKIND_LOSSY\x10\x00\x12\x11\n\rKIND_RELIABLE\x10\x01\x42\x10\xaa\x02\rLiveKit.Proto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'room_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\rLiveKit.Proto'
  _globals['_PUBLISHDATAREQUEST'].fields_by_name['destination_sids']._options = None
  _globals['_PUBLISHDATAREQUEST'].fields_by_name['destination_sids']._serialized_options = b'\030\001'
  _globals['_ROOMOPTIONS'].fields_by_name['e2ee']._options = None
  _globals['_ROOMOPTIONS'].fields_by_name['e2ee']._serialized_options = b'\030\001'
  _globals['_DATASTREAM_HEADER_ATTRIBUTESENTRY']._options = None
  _globals['_DATASTREAM_HEADER_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_DATASTREAM_TRAILER_ATTRIBUTESENTRY']._options = None
  _globals['_DATASTREAM_TRAILER_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_ICETRANSPORTTYPE']._serialized_start=13081
  _globals['_ICETRANSPORTTYPE']._serialized_end=13161
  _globals['_CONTINUALGATHERINGPOLICY']._serialized_start=13163
  _globals['_CONTINUALGATHERINGPOLICY']._serialized_end=13230
  _globals['_CONNECTIONQUALITY']._serialized_start=13232
  _globals['_CONNECTIONQUALITY']._serialized_end=13328
  _globals['_CONNECTIONSTATE']._serialized_start=13330
  _globals['_CONNECTIONSTATE']._serialized_end=13413
  _globals['_DATAPACKETKIND']._serialized_start=13415
  _globals['_DATAPACKETKIND']._serialized_end=13466
  _globals['_CONNECTREQUEST']._serialized_start=138
  _globals['_CONNECTREQUEST']._serialized_end=227
  _globals['_CONNECTRESPONSE']._serialized_start=229
  _globals['_CONNECTRESPONSE']._serialized_end=264
  _globals['_CONNECTCALLBACK']._serialized_start=267
  _globals['_CONNECTCALLBACK']._serialized_end=714
  _globals['_CONNECTCALLBACK_PARTICIPANTWITHTRACKS']._serialized_start=379
  _globals['_CONNECTCALLBACK_PARTICIPANTWITHTRACKS']._serialized_end=516
  _globals['_CONNECTCALLBACK_RESULT']._serialized_start=519
  _globals['_CONNECTCALLBACK_RESULT']._serialized_end=703
  _globals['_DISCONNECTREQUEST']._serialized_start=716
  _globals['_DISCONNECTREQUEST']._serialized_end=756
  _globals['_DISCONNECTRESPONSE']._serialized_start=758
  _globals['_DISCONNECTRESPONSE']._serialized_end=796
  _globals['_DISCONNECTCALLBACK']._serialized_start=798
  _globals['_DISCONNECTCALLBACK']._serialized_end=836
  _globals['_PUBLISHTRACKREQUEST']._serialized_start=839
  _globals['_PUBLISHTRACKREQUEST']._serialized_end=969
  _globals['_PUBLISHTRACKRESPONSE']._serialized_start=971
  _globals['_PUBLISHTRACKRESPONSE']._serialized_end=1011
  _globals['_PUBLISHTRACKCALLBACK']._serialized_start=1014
  _globals['_PUBLISHTRACKCALLBACK']._serialized_end=1143
  _globals['_UNPUBLISHTRACKREQUEST']._serialized_start=1145
  _globals['_UNPUBLISHTRACKREQUEST']._serialized_end=1248
  _globals['_UNPUBLISHTRACKRESPONSE']._serialized_start=1250
  _globals['_UNPUBLISHTRACKRESPONSE']._serialized_end=1292
  _globals['_UNPUBLISHTRACKCALLBACK']._serialized_start=1294
  _globals['_UNPUBLISHTRACKCALLBACK']._serialized_end=1351
  _globals['_PUBLISHDATAREQUEST']._serialized_start=1354
  _globals['_PUBLISHDATAREQUEST']._serialized_end=1539
  _globals['_PUBLISHDATARESPONSE']._serialized_start=1541
  _globals['_PUBLISHDATARESPONSE']._serialized_end=1580
  _globals['_PUBLISHDATACALLBACK']._serialized_start=1582
  _globals['_PUBLISHDATACALLBACK']._serialized_end=1636
  _globals['_PUBLISHTRANSCRIPTIONREQUEST']._serialized_start=1639
  _globals['_PUBLISHTRANSCRIPTIONREQUEST']._serialized_end=1805
  _globals['_PUBLISHTRANSCRIPTIONRESPONSE']._serialized_start=1807
  _globals['_PUBLISHTRANSCRIPTIONRESPONSE']._serialized_end=1855
  _globals['_PUBLISHTRANSCRIPTIONCALLBACK']._serialized_start=1857
  _globals['_PUBLISHTRANSCRIPTIONCALLBACK']._serialized_end=1920
  _globals['_PUBLISHSIPDTMFREQUEST']._serialized_start=1922
  _globals['_PUBLISHSIPDTMFREQUEST']._serialized_end=2040
  _globals['_PUBLISHSIPDTMFRESPONSE']._serialized_start=2042
  _globals['_PUBLISHSIPDTMFRESPONSE']._serialized_end=2084
  _globals['_PUBLISHSIPDTMFCALLBACK']._serialized_start=2086
  _globals['_PUBLISHSIPDTMFCALLBACK']._serialized_end=2143
  _globals['_SETLOCALMETADATAREQUEST']._serialized_start=2145
  _globals['_SETLOCALMETADATAREQUEST']._serialized_end=2222
  _globals['_SETLOCALMETADATARESPONSE']._serialized_start=2224
  _globals['_SETLOCALMETADATARESPONSE']._serialized_end=2268
  _globals['_SETLOCALMETADATACALLBACK']._serialized_start=2270
  _globals['_SETLOCALMETADATACALLBACK']._serialized_end=2329
  _globals['_SENDCHATMESSAGEREQUEST']._serialized_start=2332
  _globals['_SENDCHATMESSAGEREQUEST']._serialized_end=2464
  _globals['_EDITCHATMESSAGEREQUEST']._serialized_start=2467
  _globals['_EDITCHATMESSAGEREQUEST']._serialized_end=2655
  _globals['_SENDCHATMESSAGERESPONSE']._serialized_start=2657
  _globals['_SENDCHATMESSAGERESPONSE']._serialized_end=2700
  _globals['_SENDCHATMESSAGECALLBACK']._serialized_start=2702
  _globals['_SENDCHATMESSAGECALLBACK']._serialized_end=2825
  _globals['_SETLOCALATTRIBUTESREQUEST']._serialized_start=2827
  _globals['_SETLOCALATTRIBUTESREQUEST']._serialized_end=2940
  _globals['_ATTRIBUTESENTRY']._serialized_start=2942
  _globals['_ATTRIBUTESENTRY']._serialized_end=2987
  _globals['_SETLOCALATTRIBUTESRESPONSE']._serialized_start=2989
  _globals['_SETLOCALATTRIBUTESRESPONSE']._serialized_end=3035
  _globals['_SETLOCALATTRIBUTESCALLBACK']._serialized_start=3037
  _globals['_SETLOCALATTRIBUTESCALLBACK']._serialized_end=3098
  _globals['_SETLOCALNAMEREQUEST']._serialized_start=3100
  _globals['_SETLOCALNAMEREQUEST']._serialized_end=3169
  _globals['_SETLOCALNAMERESPONSE']._serialized_start=3171
  _globals['_SETLOCALNAMERESPONSE']._serialized_end=3211
  _globals['_SETLOCALNAMECALLBACK']._serialized_start=3213
  _globals['_SETLOCALNAMECALLBACK']._serialized_end=3268
  _globals['_SETSUBSCRIBEDREQUEST']._serialized_start=3270
  _globals['_SETSUBSCRIBEDREQUEST']._serialized_end=3339
  _globals['_SETSUBSCRIBEDRESPONSE']._serialized_start=3341
  _globals['_SETSUBSCRIBEDRESPONSE']._serialized_end=3364
  _globals['_GETSESSIONSTATSREQUEST']._serialized_start=3366
  _globals['_GETSESSIONSTATSREQUEST']._serialized_end=3411
  _globals['_GETSESSIONSTATSRESPONSE']._serialized_start=3413
  _globals['_GETSESSIONSTATSRESPONSE']._serialized_end=3456
  _globals['_GETSESSIONSTATSCALLBACK']._serialized_start=3459
  _globals['_GETSESSIONSTATSCALLBACK']._serialized_end=3706
  _globals['_GETSESSIONSTATSCALLBACK_RESULT']._serialized_start=3586
  _globals['_GETSESSIONSTATSCALLBACK_RESULT']._serialized_end=3695
  _globals['_VIDEOENCODING']._serialized_start=3708
  _globals['_VIDEOENCODING']._serialized_end=3767
  _globals['_AUDIOENCODING']._serialized_start=3769
  _globals['_AUDIOENCODING']._serialized_end=3805
  _globals['_TRACKPUBLISHOPTIONS']._serialized_start=3808
  _globals['_TRACKPUBLISHOPTIONS']._serialized_end=4117
  _globals['_ICESERVER']._serialized_start=4119
  _globals['_ICESERVER']._serialized_end=4180
  _globals['_RTCCONFIG']._serialized_start=4183
  _globals['_RTCCONFIG']._serialized_end=4379
  _globals['_ROOMOPTIONS']._serialized_start=4382
  _globals['_ROOMOPTIONS']._serialized_end=4624
  _globals['_TRANSCRIPTIONSEGMENT']._serialized_start=4626
  _globals['_TRANSCRIPTIONSEGMENT']._serialized_end=4745
  _globals['_BUFFERINFO']._serialized_start=4747
  _globals['_BUFFERINFO']._serialized_end=4795
  _globals['_OWNEDBUFFER']._serialized_start=4797
  _globals['_OWNEDBUFFER']._serialized_end=4898
  _globals['_ROOMEVENT']._serialized_start=4901
  _globals['_ROOMEVENT']._serialized_end=7503
  _globals['_ROOMINFO']._serialized_start=7506
  _globals['_ROOMINFO']._serialized_end=7835
  _globals['_OWNEDROOM']._serialized_start=7837
  _globals['_OWNEDROOM']._serialized_end=7934
  _globals['_PARTICIPANTSUPDATED']._serialized_start=7936
  _globals['_PARTICIPANTSUPDATED']._serialized_end=8011
  _globals['_PARTICIPANTCONNECTED']._serialized_start=8013
  _globals['_PARTICIPANTCONNECTED']._serialized_end=8082
  _globals['_PARTICIPANTDISCONNECTED']._serialized_start=8084
  _globals['_PARTICIPANTDISCONNECTED']._serialized_end=8199
  _globals['_LOCALTRACKPUBLISHED']._serialized_start=8201
  _globals['_LOCALTRACKPUBLISHED']._serialized_end=8241
  _globals['_LOCALTRACKUNPUBLISHED']._serialized_start=8243
  _globals['_LOCALTRACKUNPUBLISHED']._serialized_end=8291
  _globals['_LOCALTRACKSUBSCRIBED']._serialized_start=8293
  _globals['_LOCALTRACKSUBSCRIBED']._serialized_end=8334
  _globals['_TRACKPUBLISHED']._serialized_start=8336
  _globals['_TRACKPUBLISHED']._serialized_end=8441
  _globals['_TRACKUNPUBLISHED']._serialized_start=8443
  _globals['_TRACKUNPUBLISHED']._serialized_end=8516
  _globals['_TRACKSUBSCRIBED']._serialized_start=8518
  _globals['_TRACKSUBSCRIBED']._serialized_end=8607
  _globals['_TRACKUNSUBSCRIBED']._serialized_start=8609
  _globals['_TRACKUNSUBSCRIBED']._serialized_end=8677
  _globals['_TRACKSUBSCRIPTIONFAILED']._serialized_start=8679
  _globals['_TRACKSUBSCRIPTIONFAILED']._serialized_end=8768
  _globals['_TRACKMUTED']._serialized_start=8770
  _globals['_TRACKMUTED']._serialized_end=8831
  _globals['_TRACKUNMUTED']._serialized_start=8833
  _globals['_TRACKUNMUTED']._serialized_end=8896
  _globals['_E2EESTATECHANGED']._serialized_start=8898
  _globals['_E2EESTATECHANGED']._serialized_end=8993
  _globals['_ACTIVESPEAKERSCHANGED']._serialized_start=8995
  _globals['_ACTIVESPEAKERSCHANGED']._serialized_end=9050
  _globals['_ROOMMETADATACHANGED']._serialized_start=9052
  _globals['_ROOMMETADATACHANGED']._serialized_end=9091
  _globals['_ROOMSIDCHANGED']._serialized_start=9093
  _globals['_ROOMSIDCHANGED']._serialized_end=9122
  _globals['_PARTICIPANTMETADATACHANGED']._serialized_start=9124
  _globals['_PARTICIPANTMETADATACHANGED']._serialized_end=9200
  _globals['_PARTICIPANTATTRIBUTESCHANGED']._serialized_start=9203
  _globals['_PARTICIPANTATTRIBUTESCHANGED']._serialized_end=9375
  _globals['_PARTICIPANTENCRYPTIONSTATUSCHANGED']._serialized_start=9377
  _globals['_PARTICIPANTENCRYPTIONSTATUSCHANGED']._serialized_end=9465
  _globals['_PARTICIPANTNAMECHANGED']._serialized_start=9467
  _globals['_PARTICIPANTNAMECHANGED']._serialized_end=9535
  _globals['_CONNECTIONQUALITYCHANGED']._serialized_start=9537
  _globals['_CONNECTIONQUALITYCHANGED']._serialized_end=9644
  _globals['_USERPACKET']._serialized_start=9646
  _globals['_USERPACKET']._serialized_end=9715
  _globals['_CHATMESSAGE']._serialized_start=9717
  _globals['_CHATMESSAGE']._serialized_end=9838
  _globals['_CHATMESSAGERECEIVED']._serialized_start=9840
  _globals['_CHATMESSAGERECEIVED']._serialized_end=9936
  _globals['_SIPDTMF']._serialized_start=9938
  _globals['_SIPDTMF']._serialized_end=9976
  _globals['_DATAPACKETRECEIVED']._serialized_start=9979
  _globals['_DATAPACKETRECEIVED']._serialized_end=10170
  _globals['_TRANSCRIPTIONRECEIVED']._serialized_start=10172
  _globals['_TRANSCRIPTIONRECEIVED']._serialized_end=10299
  _globals['_CONNECTIONSTATECHANGED']._serialized_start=10301
  _globals['_CONNECTIONSTATECHANGED']._serialized_end=10372
  _globals['_CONNECTED']._serialized_start=10374
  _globals['_CONNECTED']._serialized_end=10385
  _globals['_DISCONNECTED']._serialized_start=10387
  _globals['_DISCONNECTED']._serialized_end=10450
  _globals['_RECONNECTING']._serialized_start=10452
  _globals['_RECONNECTING']._serialized_end=10466
  _globals['_RECONNECTED']._serialized_start=10468
  _globals['_RECONNECTED']._serialized_end=10481
  _globals['_ROOMEOS']._serialized_start=10483
  _globals['_ROOMEOS']._serialized_end=10492
  _globals['_DATASTREAM']._serialized_start=10495
  _globals['_DATASTREAM']._serialized_end=11405
  _globals['_DATASTREAM_TEXTHEADER']._serialized_start=10510
  _globals['_DATASTREAM_TEXTHEADER']._serialized_end=10680
  _globals['_DATASTREAM_BYTEHEADER']._serialized_start=10682
  _globals['_DATASTREAM_BYTEHEADER']._serialized_end=10708
  _globals['_DATASTREAM_HEADER']._serialized_start=10711
  _globals['_DATASTREAM_HEADER']._serialized_end=11074
  _globals['_DATASTREAM_HEADER_ATTRIBUTESENTRY']._serialized_start=11007
  _globals['_DATASTREAM_HEADER_ATTRIBUTESENTRY']._serialized_end=11056
  _globals['_DATASTREAM_CHUNK']._serialized_start=11076
  _globals['_DATASTREAM_CHUNK']._serialized_end=11169
  _globals['_DATASTREAM_TRAILER']._serialized_start=11172
  _globals['_DATASTREAM_TRAILER']._serialized_end=11338
  _globals['_DATASTREAM_TRAILER_ATTRIBUTESENTRY']._serialized_start=11007
  _globals['_DATASTREAM_TRAILER_ATTRIBUTESENTRY']._serialized_end=11056
  _globals['_DATASTREAM_OPERATIONTYPE']._serialized_start=11340
  _globals['_DATASTREAM_OPERATIONTYPE']._serialized_end=11405
  _globals['_DATASTREAMHEADERRECEIVED']._serialized_start=11407
  _globals['_DATASTREAMHEADERRECEIVED']._serialized_end=11513
  _globals['_DATASTREAMCHUNKRECEIVED']._serialized_start=11515
  _globals['_DATASTREAMCHUNKRECEIVED']._serialized_end=11618
  _globals['_DATASTREAMTRAILERRECEIVED']._serialized_start=11620
  _globals['_DATASTREAMTRAILERRECEIVED']._serialized_end=11729
  _globals['_SENDSTREAMHEADERREQUEST']._serialized_start=11732
  _globals['_SENDSTREAMHEADERREQUEST']._serialized_end=11898
  _globals['_SENDSTREAMCHUNKREQUEST']._serialized_start=11901
  _globals['_SENDSTREAMCHUNKREQUEST']._serialized_end=12064
  _globals['_SENDSTREAMTRAILERREQUEST']._serialized_start=12067
  _globals['_SENDSTREAMTRAILERREQUEST']._serialized_end=12236
  _globals['_SENDSTREAMHEADERRESPONSE']._serialized_start=12238
  _globals['_SENDSTREAMHEADERRESPONSE']._serialized_end=12282
  _globals['_SENDSTREAMCHUNKRESPONSE']._serialized_start=12284
  _globals['_SENDSTREAMCHUNKRESPONSE']._serialized_end=12327
  _globals['_SENDSTREAMTRAILERRESPONSE']._serialized_start=12329
  _globals['_SENDSTREAMTRAILERRESPONSE']._serialized_end=12374
  _globals['_SENDSTREAMHEADERCALLBACK']._serialized_start=12376
  _globals['_SENDSTREAMHEADERCALLBACK']._serialized_end=12435
  _globals['_SENDSTREAMCHUNKCALLBACK']._serialized_start=12437
  _globals['_SENDSTREAMCHUNKCALLBACK']._serialized_end=12495
  _globals['_SENDSTREAMTRAILERCALLBACK']._serialized_start=12497
  _globals['_SENDSTREAMTRAILERCALLBACK']._serialized_end=12557
  _globals['_SETDATACHANNELBUFFEREDAMOUNTLOWTHRESHOLDREQUEST']._serialized_start=12560
  _globals['_SETDATACHANNELBUFFEREDAMOUNTLOWTHRESHOLDREQUEST']._serialized_end=12707
  _globals['_SETDATACHANNELBUFFEREDAMOUNTLOWTHRESHOLDRESPONSE']._serialized_start=12709
  _globals['_SETDATACHANNELBUFFEREDAMOUNTLOWTHRESHOLDRESPONSE']._serialized_end=12759
  _globals['_DATACHANNELBUFFEREDAMOUNTLOWTHRESHOLDCHANGED']._serialized_start=12761
  _globals['_DATACHANNELBUFFEREDAMOUNTLOWTHRESHOLDCHANGED']._serialized_end=12871
  _globals['_BYTESTREAMOPENED']._serialized_start=12873
  _globals['_BYTESTREAMOPENED']._serialized_end=12975
  _globals['_TEXTSTREAMOPENED']._serialized_start=12977
  _globals['_TEXTSTREAMOPENED']._serialized_end=13079
# @@protoc_insertion_point(module_scope)



# type: ignore

from typing import AsyncIterator
import numpy as np
import pytest
import matplotlib.pyplot as plt

from livekit.rtc import AudioMixer
from livekit.rtc.audio_frame import AudioFrame

SAMPLE_RATE = 48000
# Use 100ms blocks (i.e. 1600 samples per frame)
BLOCKSIZE = SAMPLE_RATE // 10


async def sine_wave_generator(freq: float, duration: float) -> AsyncIterator[AudioFrame]:
    total_frames = int((duration * SAMPLE_RATE) // BLOCKSIZE)
    t_frame = np.arange(BLOCKSIZE) / SAMPLE_RATE
    for i in range(total_frames):
        # Shift the time for each frame so that the sine wave is continuous
        t = t_frame + i * BLOCKSIZE / SAMPLE_RATE
        # Create a sine wave with amplitude 0.3 (to avoid clipping when summing)
        signal = 0.3 * np.sin(2 * np.pi * freq * t)
        # Convert from float [-0.5, 0.5] to int16 values
        signal_int16 = np.int16(signal * 32767)
        frame = AudioFrame(
            signal_int16.tobytes(),
            SAMPLE_RATE,
            1,
            BLOCKSIZE,
        )
        yield frame


@pytest.mark.asyncio
async def test_mixer_two_sine_waves():
    """
    Test that mixing two sine waves (440Hz and 880Hz) produces an output
    containing both frequency components.
    """
    duration = 1.0
    mixer = AudioMixer(
        sample_rate=SAMPLE_RATE,
        num_channels=1,
        blocksize=BLOCKSIZE,
        stream_timeout_ms=100,
        capacity=100,
    )
    stream1 = sine_wave_generator(440, duration)
    stream2 = sine_wave_generator(880, duration)
    mixer.add_stream(stream1)
    mixer.add_stream(stream2)
    mixer.end_input()

    mixed_signals = []
    async for frame in mixer:
        data = np.frombuffer(frame.data.tobytes(), dtype=np.int16)
        mixed_signals.append(data)

    await mixer.aclose()

    if not mixed_signals:
        pytest.fail("No frames were produced by the mixer.")

    mixed_signal = np.concatenate(mixed_signals)

    plt.figure(figsize=(10, 4))
    plt.plot(mixed_signal[:1000])  # plot 1000
    plt.title("Mixed Signal")
    plt.xlabel("Sample")
    plt.ylabel("Amplitude")
    plt.show()

    # Use FFT to analyze frequency components.
    fft = np.fft.rfft(mixed_signal)
    freqs = np.fft.rfftfreq(len(mixed_signal), 1 / SAMPLE_RATE)
    magnitude = np.abs(fft)

    # Identify peak frequencies. We'll pick the 5 highest peaks.
    peak_indices = np.argsort(magnitude)[-5:]
    peak_freqs = freqs[peak_indices]

    print("Peak frequencies:", peak_freqs)

    # Assert that the peaks include 440Hz and 880Hz (with a tolerance of ±5 Hz)
    assert any(np.isclose(peak_freqs, 440, atol=5)), f"Expected 440 Hz in peaks, got: {peak_freqs}"
    assert any(np.isclose(peak_freqs, 880, atol=5)), f"Expected 880 Hz in peaks, got: {peak_freqs}"



import asyncio
import numpy as np
import contextlib
from dataclasses import dataclass
from typing import AsyncIterator, Optional
from .audio_frame import AudioFrame
from .log import logger

_Stream = AsyncIterator[AudioFrame]


@dataclass
class _Contribution:
    stream: _Stream
    data: np.ndarray
    buffer: np.ndarray
    had_data: bool
    exhausted: bool


class AudioMixer:
    def __init__(
        self,
        sample_rate: int,
        num_channels: int,
        *,
        blocksize: int = 0,
        stream_timeout_ms: int = 100,
        capacity: int = 100,
    ) -> None:
        """
        Initialize the AudioMixer.

        The mixer accepts multiple async audio streams and mixes them into a single output stream.
        Each output frame is generated with a fixed chunk size determined by the blocksize (in samples).
        If blocksize is not provided (or 0), it defaults to 100ms.

        Each input stream is processed in parallel, accumulating audio data until at least one chunk
        of samples is available. If an input stream does not provide data within the specified timeout,
        a warning is logged. The mixer can be closed immediately
        (dropping unconsumed frames) or allowed to flush remaining data using end_input().

        Args:
            sample_rate (int): The audio sample rate in Hz.
            num_channels (int): The number of audio channels.
            blocksize (int, optional): The size of the audio block (in samples) for mixing. If not provided,
                defaults to sample_rate // 10.
            stream_timeout_ms (int, optional): The maximum wait time in milliseconds for each stream to provide
                audio data before timing out. Defaults to 100 ms.
            capacity (int, optional): The maximum number of mixed frames to store in the output queue.
                Defaults to 100.
        """
        self._streams: set[_Stream] = set()
        self._buffers: dict[_Stream, np.ndarray] = {}
        self._sample_rate: int = sample_rate
        self._num_channels: int = num_channels
        self._chunk_size: int = blocksize if blocksize > 0 else int(sample_rate // 10)
        self._stream_timeout_ms: int = stream_timeout_ms
        self._queue: asyncio.Queue[Optional[AudioFrame]] = asyncio.Queue(maxsize=capacity)
        # _ending signals that no new streams will be added,
        # but we continue processing until all streams are exhausted.
        self._ending: bool = False
        self._mixer_task: asyncio.Task = asyncio.create_task(self._mixer())

    def add_stream(self, stream: AsyncIterator[AudioFrame]) -> None:
        """
        Add an audio stream to the mixer.

        The stream is added to the internal set of streams and an empty buffer is initialized for it,
        if not already present.

        Args:
            stream (AsyncIterator[AudioFrame]): An async iterator that produces AudioFrame objects.
        """
        if self._ending:
            raise RuntimeError("Cannot add stream after mixer has been closed")

        self._streams.add(stream)
        if stream not in self._buffers:
            self._buffers[stream] = np.empty((0, self._num_channels), dtype=np.int16)

    def remove_stream(self, stream: AsyncIterator[AudioFrame]) -> None:
        """
        Remove an audio stream from the mixer.

        This method removes the specified stream and its associated buffer from the mixer.

        Args:
            stream (AsyncIterator[AudioFrame]): The audio stream to remove.
        """
        self._streams.discard(stream)
        self._buffers.pop(stream, None)

    def __aiter__(self) -> "AudioMixer":
        return self

    async def __anext__(self) -> AudioFrame:
        item = await self._queue.get()
        if item is None:
            raise StopAsyncIteration
        return item

    async def aclose(self) -> None:
        """
        Immediately stop mixing and close the mixer.

        This cancels the mixing task, and any unconsumed output in the queue may be dropped.
        """
        self._ending = True
        self._mixer_task.cancel()
        with contextlib.suppress(asyncio.CancelledError):
            await self._mixer_task

    def end_input(self) -> None:
        """
        Signal that no more streams will be added.

        This method marks the mixer as closed so that it flushes any remaining buffered output before ending.
        Note that existing streams will still be processed until exhausted.
        """
        self._ending = True

    async def _mixer(self) -> None:
        while True:
            # If we're in ending mode and there are no more streams, exit.
            if self._ending and not self._streams:
                break

            if not self._streams:
                await asyncio.sleep(0.01)
                continue

            tasks = [
                self._get_contribution(
                    stream,
                    self._buffers.get(stream, np.empty((0, self._num_channels), dtype=np.int16)),
                )
                for stream in list(self._streams)
            ]
            results = await asyncio.gather(*tasks, return_exceptions=True)
            contributions = []
            any_data = False
            removals = []
            for contrib in results:
                if not isinstance(contrib, _Contribution):
                    continue

                contributions.append(contrib.data.astype(np.float32))
                self._buffers[contrib.stream] = contrib.buffer
                if contrib.had_data:
                    any_data = True
                if contrib.exhausted and contrib.buffer.shape[0] == 0:
                    removals.append(contrib.stream)

            for stream in removals:
                self.remove_stream(stream)

            if not any_data:
                await asyncio.sleep(0.001)
                continue

            mixed = np.sum(np.stack(contributions, axis=0), axis=0)
            mixed = np.clip(mixed, -32768, 32767).astype(np.int16)
            frame = AudioFrame(
                mixed.tobytes(), self._sample_rate, self._num_channels, self._chunk_size
            )
            await self._queue.put(frame)

        await self._queue.put(None)

    async def _get_contribution(
        self, stream: AsyncIterator[AudioFrame], buf: np.ndarray
    ) -> _Contribution:
        had_data = buf.shape[0] > 0
        exhausted = False
        while buf.shape[0] < self._chunk_size and not exhausted:
            try:
                frame = await asyncio.wait_for(
                    stream.__anext__(), timeout=self._stream_timeout_ms / 1000
                )
            except asyncio.TimeoutError:
                logger.warning(f"AudioMixer: stream {stream} timeout, ignoring")
                break
            except StopAsyncIteration:
                exhausted = True
                break
            new_data = np.frombuffer(frame.data.tobytes(), dtype=np.int16).reshape(
                -1, self._num_channels
            )
            buf = np.concatenate((buf, new_data), axis=0) if buf.size else new_data
            had_data = True
        if buf.shape[0] >= self._chunk_size:
            contrib, buf = buf[: self._chunk_size], buf[self._chunk_size :]
        else:
            pad = np.zeros((self._chunk_size - buf.shape[0], self._num_channels), dtype=np.int16)
            contrib, buf = (
                np.concatenate((buf, pad), axis=0),
                np.empty((0, self._num_channels), dtype=np.int16),
            )
        return _Contribution(stream, contrib, buf, had_data, exhausted)



# Copyright 2023 LiveKit, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ._ffi_client import FfiHandle, FfiClient
from ._proto import ffi_pb2 as proto_ffi
from ._proto import video_frame_pb2 as proto_video
from .video_frame import VideoFrame


class VideoSource:
    def __init__(self, width: int, height: int) -> None:
        req = proto_ffi.FfiRequest()
        req.new_video_source.type = proto_video.VideoSourceType.VIDEO_SOURCE_NATIVE
        req.new_video_source.resolution.width = width
        req.new_video_source.resolution.height = height

        resp = FfiClient.instance.request(req)
        self._info = resp.new_video_source.source
        self._ffi_handle = FfiHandle(self._info.handle.id)

    def capture_frame(
        self,
        frame: VideoFrame,
        *,
        timestamp_us: int = 0,
        rotation: proto_video.VideoRotation.ValueType = proto_video.VideoRotation.VIDEO_ROTATION_0,
    ) -> None:
        req = proto_ffi.FfiRequest()
        req.capture_video_frame.source_handle = self._ffi_handle.handle
        req.capture_video_frame.buffer.CopyFrom(frame._proto_info())
        req.capture_video_frame.rotation = rotation
        req.capture_video_frame.timestamp_us = timestamp_us
        FfiClient.instance.request(req)

    async def aclose(self) -> None:
        self._ffi_handle.dispose()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: audio_frame.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import handle_pb2 as handle__pb2
from . import track_pb2 as track__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61udio_frame.proto\x12\rlivekit.proto\x1a\x0chandle.proto\x1a\x0btrack.proto\"\xdb\x01\n\x15NewAudioStreamRequest\x12\x14\n\x0ctrack_handle\x18\x01 \x02(\x04\x12,\n\x04type\x18\x02 \x02(\x0e\x32\x1e.livekit.proto.AudioStreamType\x12\x13\n\x0bsample_rate\x18\x03 \x01(\r\x12\x14\n\x0cnum_channels\x18\x04 \x01(\r\x12\x1e\n\x16\x61udio_filter_module_id\x18\x05 \x01(\t\x12\x1c\n\x14\x61udio_filter_options\x18\x06 \x01(\t\x12\x15\n\rframe_size_ms\x18\x07 \x01(\r\"I\n\x16NewAudioStreamResponse\x12/\n\x06stream\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedAudioStream\"\x9f\x02\n!AudioStreamFromParticipantRequest\x12\x1a\n\x12participant_handle\x18\x01 \x02(\x04\x12,\n\x04type\x18\x02 \x02(\x0e\x32\x1e.livekit.proto.AudioStreamType\x12\x30\n\x0ctrack_source\x18\x03 \x01(\x0e\x32\x1a.livekit.proto.TrackSource\x12\x13\n\x0bsample_rate\x18\x05 \x01(\r\x12\x14\n\x0cnum_channels\x18\x06 \x01(\r\x12\x1e\n\x16\x61udio_filter_module_id\x18\x07 \x01(\t\x12\x1c\n\x14\x61udio_filter_options\x18\x08 \x01(\t\x12\x15\n\rframe_size_ms\x18\t \x01(\r\"U\n\"AudioStreamFromParticipantResponse\x12/\n\x06stream\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedAudioStream\"\xbb\x01\n\x15NewAudioSourceRequest\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.AudioSourceType\x12\x32\n\x07options\x18\x02 \x01(\x0b\x32!.livekit.proto.AudioSourceOptions\x12\x13\n\x0bsample_rate\x18\x03 \x02(\r\x12\x14\n\x0cnum_channels\x18\x04 \x02(\r\x12\x15\n\rqueue_size_ms\x18\x05 \x01(\r\"I\n\x16NewAudioSourceResponse\x12/\n\x06source\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedAudioSource\"f\n\x18\x43\x61ptureAudioFrameRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x04\x12\x33\n\x06\x62uffer\x18\x02 \x02(\x0b\x32#.livekit.proto.AudioFrameBufferInfo\"-\n\x19\x43\x61ptureAudioFrameResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"<\n\x19\x43\x61ptureAudioFrameCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"0\n\x17\x43learAudioBufferRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x04\"\x1a\n\x18\x43learAudioBufferResponse\"\x1a\n\x18NewAudioResamplerRequest\"R\n\x19NewAudioResamplerResponse\x12\x35\n\tresampler\x18\x01 \x02(\x0b\x32\".livekit.proto.OwnedAudioResampler\"\x93\x01\n\x17RemixAndResampleRequest\x12\x18\n\x10resampler_handle\x18\x01 \x02(\x04\x12\x33\n\x06\x62uffer\x18\x02 \x02(\x0b\x32#.livekit.proto.AudioFrameBufferInfo\x12\x14\n\x0cnum_channels\x18\x03 \x02(\r\x12\x13\n\x0bsample_rate\x18\x04 \x02(\r\"P\n\x18RemixAndResampleResponse\x12\x34\n\x06\x62uffer\x18\x01 \x02(\x0b\x32$.livekit.proto.OwnedAudioFrameBuffer\"\x95\x01\n\rNewApmRequest\x12\x1e\n\x16\x65\x63ho_canceller_enabled\x18\x01 \x02(\x08\x12\x1f\n\x17gain_controller_enabled\x18\x02 \x02(\x08\x12 \n\x18high_pass_filter_enabled\x18\x03 \x02(\x08\x12!\n\x19noise_suppression_enabled\x18\x04 \x02(\x08\"6\n\x0eNewApmResponse\x12$\n\x03\x61pm\x18\x01 \x02(\x0b\x32\x17.livekit.proto.OwnedApm\"x\n\x17\x41pmProcessStreamRequest\x12\x12\n\napm_handle\x18\x01 \x02(\x04\x12\x10\n\x08\x64\x61ta_ptr\x18\x02 \x02(\x04\x12\x0c\n\x04size\x18\x03 \x02(\r\x12\x13\n\x0bsample_rate\x18\x04 \x02(\r\x12\x14\n\x0cnum_channels\x18\x05 \x02(\r\")\n\x18\x41pmProcessStreamResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x7f\n\x1e\x41pmProcessReverseStreamRequest\x12\x12\n\napm_handle\x18\x01 \x02(\x04\x12\x10\n\x08\x64\x61ta_ptr\x18\x02 \x02(\x04\x12\x0c\n\x04size\x18\x03 \x02(\r\x12\x13\n\x0bsample_rate\x18\x04 \x02(\r\x12\x14\n\x0cnum_channels\x18\x05 \x02(\r\"0\n\x1f\x41pmProcessReverseStreamResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"@\n\x18\x41pmSetStreamDelayRequest\x12\x12\n\napm_handle\x18\x01 \x02(\x04\x12\x10\n\x08\x64\x65lay_ms\x18\x02 \x02(\x05\"*\n\x19\x41pmSetStreamDelayResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x9c\x02\n\x16NewSoxResamplerRequest\x12\x12\n\ninput_rate\x18\x01 \x02(\x01\x12\x13\n\x0boutput_rate\x18\x02 \x02(\x01\x12\x14\n\x0cnum_channels\x18\x03 \x02(\r\x12<\n\x0finput_data_type\x18\x04 \x02(\x0e\x32#.livekit.proto.SoxResamplerDataType\x12=\n\x10output_data_type\x18\x05 \x02(\x0e\x32#.livekit.proto.SoxResamplerDataType\x12\x37\n\x0equality_recipe\x18\x06 \x02(\x0e\x32\x1f.livekit.proto.SoxQualityRecipe\x12\r\n\x05\x66lags\x18\x07 \x01(\r\"l\n\x17NewSoxResamplerResponse\x12\x35\n\tresampler\x18\x01 \x01(\x0b\x32 .livekit.proto.OwnedSoxResamplerH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"S\n\x17PushSoxResamplerRequest\x12\x18\n\x10resampler_handle\x18\x01 \x02(\x04\x12\x10\n\x08\x64\x61ta_ptr\x18\x02 \x02(\x04\x12\x0c\n\x04size\x18\x03 \x02(\r\"K\n\x18PushSoxResamplerResponse\x12\x12\n\noutput_ptr\x18\x01 \x02(\x04\x12\x0c\n\x04size\x18\x02 \x02(\r\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"4\n\x18\x46lushSoxResamplerRequest\x12\x18\n\x10resampler_handle\x18\x01 \x02(\x04\"L\n\x19\x46lushSoxResamplerResponse\x12\x12\n\noutput_ptr\x18\x01 \x02(\x04\x12\x0c\n\x04size\x18\x02 \x02(\r\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"p\n\x14\x41udioFrameBufferInfo\x12\x10\n\x08\x64\x61ta_ptr\x18\x01 \x02(\x04\x12\x14\n\x0cnum_channels\x18\x02 \x02(\r\x12\x13\n\x0bsample_rate\x18\x03 \x02(\r\x12\x1b\n\x13samples_per_channel\x18\x04 \x02(\r\"y\n\x15OwnedAudioFrameBuffer\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12\x31\n\x04info\x18\x02 \x02(\x0b\x32#.livekit.proto.AudioFrameBufferInfo\"?\n\x0f\x41udioStreamInfo\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.AudioStreamType\"o\n\x10OwnedAudioStream\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12,\n\x04info\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.AudioStreamInfo\"\x9f\x01\n\x10\x41udioStreamEvent\x12\x15\n\rstream_handle\x18\x01 \x02(\x04\x12;\n\x0e\x66rame_received\x18\x02 \x01(\x0b\x32!.livekit.proto.AudioFrameReceivedH\x00\x12,\n\x03\x65os\x18\x03 \x01(\x0b\x32\x1d.livekit.proto.AudioStreamEOSH\x00\x42\t\n\x07message\"I\n\x12\x41udioFrameReceived\x12\x33\n\x05\x66rame\x18\x01 \x02(\x0b\x32$.livekit.proto.OwnedAudioFrameBuffer\"\x10\n\x0e\x41udioStreamEOS\"e\n\x12\x41udioSourceOptions\x12\x19\n\x11\x65\x63ho_cancellation\x18\x01 \x02(\x08\x12\x19\n\x11noise_suppression\x18\x02 \x02(\x08\x12\x19\n\x11\x61uto_gain_control\x18\x03 \x02(\x08\"?\n\x0f\x41udioSourceInfo\x12,\n\x04type\x18\x02 \x02(\x0e\x32\x1e.livekit.proto.AudioSourceType\"o\n\x10OwnedAudioSource\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12,\n\x04info\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.AudioSourceInfo\"\x14\n\x12\x41udioResamplerInfo\"u\n\x13OwnedAudioResampler\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12/\n\x04info\x18\x02 \x02(\x0b\x32!.livekit.proto.AudioResamplerInfo\"9\n\x08OwnedApm\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\"\x12\n\x10SoxResamplerInfo\"q\n\x11OwnedSoxResampler\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12-\n\x04info\x18\x02 \x02(\x0b\x32\x1f.livekit.proto.SoxResamplerInfo\"\\\n\x1cLoadAudioFilterPluginRequest\x12\x13\n\x0bplugin_path\x18\x01 \x02(\t\x12\x14\n\x0c\x64\x65pendencies\x18\x02 \x03(\t\x12\x11\n\tmodule_id\x18\x03 \x02(\t\".\n\x1dLoadAudioFilterPluginResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t*J\n\x14SoxResamplerDataType\x12\x18\n\x14SOXR_DATATYPE_INT16I\x10\x00\x12\x18\n\x14SOXR_DATATYPE_INT16S\x10\x01*\x8b\x01\n\x10SoxQualityRecipe\x12\x16\n\x12SOXR_QUALITY_QUICK\x10\x00\x12\x14\n\x10SOXR_QUALITY_LOW\x10\x01\x12\x17\n\x13SOXR_QUALITY_MEDIUM\x10\x02\x12\x15\n\x11SOXR_QUALITY_HIGH\x10\x03\x12\x19\n\x15SOXR_QUALITY_VERYHIGH\x10\x04*\x97\x01\n\x0bSoxFlagBits\x12\x16\n\x12SOXR_ROLLOFF_SMALL\x10\x00\x12\x17\n\x13SOXR_ROLLOFF_MEDIUM\x10\x01\x12\x15\n\x11SOXR_ROLLOFF_NONE\x10\x02\x12\x18\n\x14SOXR_HIGH_PREC_CLOCK\x10\x03\x12\x19\n\x15SOXR_DOUBLE_PRECISION\x10\x04\x12\x0b\n\x07SOXR_VR\x10\x05*A\n\x0f\x41udioStreamType\x12\x17\n\x13\x41UDIO_STREAM_NATIVE\x10\x00\x12\x15\n\x11\x41UDIO_STREAM_HTML\x10\x01**\n\x0f\x41udioSourceType\x12\x17\n\x13\x41UDIO_SOURCE_NATIVE\x10\x00\x42\x10\xaa\x02\rLiveKit.Proto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'audio_frame_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\rLiveKit.Proto'
  _globals['_SOXRESAMPLERDATATYPE']._serialized_start=4418
  _globals['_SOXRESAMPLERDATATYPE']._serialized_end=4492
  _globals['_SOXQUALITYRECIPE']._serialized_start=4495
  _globals['_SOXQUALITYRECIPE']._serialized_end=4634
  _globals['_SOXFLAGBITS']._serialized_start=4637
  _globals['_SOXFLAGBITS']._serialized_end=4788
  _globals['_AUDIOSTREAMTYPE']._serialized_start=4790
  _globals['_AUDIOSTREAMTYPE']._serialized_end=4855
  _globals['_AUDIOSOURCETYPE']._serialized_start=4857
  _globals['_AUDIOSOURCETYPE']._serialized_end=4899
  _globals['_NEWAUDIOSTREAMREQUEST']._serialized_start=64
  _globals['_NEWAUDIOSTREAMREQUEST']._serialized_end=283
  _globals['_NEWAUDIOSTREAMRESPONSE']._serialized_start=285
  _globals['_NEWAUDIOSTREAMRESPONSE']._serialized_end=358
  _globals['_AUDIOSTREAMFROMPARTICIPANTREQUEST']._serialized_start=361
  _globals['_AUDIOSTREAMFROMPARTICIPANTREQUEST']._serialized_end=648
  _globals['_AUDIOSTREAMFROMPARTICIPANTRESPONSE']._serialized_start=650
  _globals['_AUDIOSTREAMFROMPARTICIPANTRESPONSE']._serialized_end=735
  _globals['_NEWAUDIOSOURCEREQUEST']._serialized_start=738
  _globals['_NEWAUDIOSOURCEREQUEST']._serialized_end=925
  _globals['_NEWAUDIOSOURCERESPONSE']._serialized_start=927
  _globals['_NEWAUDIOSOURCERESPONSE']._serialized_end=1000
  _globals['_CAPTUREAUDIOFRAMEREQUEST']._serialized_start=1002
  _globals['_CAPTUREAUDIOFRAMEREQUEST']._serialized_end=1104
  _globals['_CAPTUREAUDIOFRAMERESPONSE']._serialized_start=1106
  _globals['_CAPTUREAUDIOFRAMERESPONSE']._serialized_end=1151
  _globals['_CAPTUREAUDIOFRAMECALLBACK']._serialized_start=1153
  _globals['_CAPTUREAUDIOFRAMECALLBACK']._serialized_end=1213
  _globals['_CLEARAUDIOBUFFERREQUEST']._serialized_start=1215
  _globals['_CLEARAUDIOBUFFERREQUEST']._serialized_end=1263
  _globals['_CLEARAUDIOBUFFERRESPONSE']._serialized_start=1265
  _globals['_CLEARAUDIOBUFFERRESPONSE']._serialized_end=1291
  _globals['_NEWAUDIORESAMPLERREQUEST']._serialized_start=1293
  _globals['_NEWAUDIORESAMPLERREQUEST']._serialized_end=1319
  _globals['_NEWAUDIORESAMPLERRESPONSE']._serialized_start=1321
  _globals['_NEWAUDIORESAMPLERRESPONSE']._serialized_end=1403
  _globals['_REMIXANDRESAMPLEREQUEST']._serialized_start=1406
  _globals['_REMIXANDRESAMPLEREQUEST']._serialized_end=1553
  _globals['_REMIXANDRESAMPLERESPONSE']._serialized_start=1555
  _globals['_REMIXANDRESAMPLERESPONSE']._serialized_end=1635
  _globals['_NEWAPMREQUEST']._serialized_start=1638
  _globals['_NEWAPMREQUEST']._serialized_end=1787
  _globals['_NEWAPMRESPONSE']._serialized_start=1789
  _globals['_NEWAPMRESPONSE']._serialized_end=1843
  _globals['_APMPROCESSSTREAMREQUEST']._serialized_start=1845
  _globals['_APMPROCESSSTREAMREQUEST']._serialized_end=1965
  _globals['_APMPROCESSSTREAMRESPONSE']._serialized_start=1967
  _globals['_APMPROCESSSTREAMRESPONSE']._serialized_end=2008
  _globals['_APMPROCESSREVERSESTREAMREQUEST']._serialized_start=2010
  _globals['_APMPROCESSREVERSESTREAMREQUEST']._serialized_end=2137
  _globals['_APMPROCESSREVERSESTREAMRESPONSE']._serialized_start=2139
  _globals['_APMPROCESSREVERSESTREAMRESPONSE']._serialized_end=2187
  _globals['_APMSETSTREAMDELAYREQUEST']._serialized_start=2189
  _globals['_APMSETSTREAMDELAYREQUEST']._serialized_end=2253
  _globals['_APMSETSTREAMDELAYRESPONSE']._serialized_start=2255
  _globals['_APMSETSTREAMDELAYRESPONSE']._serialized_end=2297
  _globals['_NEWSOXRESAMPLERREQUEST']._serialized_start=2300
  _globals['_NEWSOXRESAMPLERREQUEST']._serialized_end=2584
  _globals['_NEWSOXRESAMPLERRESPONSE']._serialized_start=2586
  _globals['_NEWSOXRESAMPLERRESPONSE']._serialized_end=2694
  _globals['_PUSHSOXRESAMPLERREQUEST']._serialized_start=2696
  _globals['_PUSHSOXRESAMPLERREQUEST']._serialized_end=2779
  _globals['_PUSHSOXRESAMPLERRESPONSE']._serialized_start=2781
  _globals['_PUSHSOXRESAMPLERRESPONSE']._serialized_end=2856
  _globals['_FLUSHSOXRESAMPLERREQUEST']._serialized_start=2858
  _globals['_FLUSHSOXRESAMPLERREQUEST']._serialized_end=2910
  _globals['_FLUSHSOXRESAMPLERRESPONSE']._serialized_start=2912
  _globals['_FLUSHSOXRESAMPLERRESPONSE']._serialized_end=2988
  _globals['_AUDIOFRAMEBUFFERINFO']._serialized_start=2990
  _globals['_AUDIOFRAMEBUFFERINFO']._serialized_end=3102
  _globals['_OWNEDAUDIOFRAMEBUFFER']._serialized_start=3104
  _globals['_OWNEDAUDIOFRAMEBUFFER']._serialized_end=3225
  _globals['_AUDIOSTREAMINFO']._serialized_start=3227
  _globals['_AUDIOSTREAMINFO']._serialized_end=3290
  _globals['_OWNEDAUDIOSTREAM']._serialized_start=3292
  _globals['_OWNEDAUDIOSTREAM']._serialized_end=3403
  _globals['_AUDIOSTREAMEVENT']._serialized_start=3406
  _globals['_AUDIOSTREAMEVENT']._serialized_end=3565
  _globals['_AUDIOFRAMERECEIVED']._serialized_start=3567
  _globals['_AUDIOFRAMERECEIVED']._serialized_end=3640
  _globals['_AUDIOSTREAMEOS']._serialized_start=3642
  _globals['_AUDIOSTREAMEOS']._serialized_end=3658
  _globals['_AUDIOSOURCEOPTIONS']._serialized_start=3660
  _globals['_AUDIOSOURCEOPTIONS']._serialized_end=3761
  _globals['_AUDIOSOURCEINFO']._serialized_start=3763
  _globals['_AUDIOSOURCEINFO']._serialized_end=3826
  _globals['_OWNEDAUDIOSOURCE']._serialized_start=3828
  _globals['_OWNEDAUDIOSOURCE']._serialized_end=3939
  _globals['_AUDIORESAMPLERINFO']._serialized_start=3941
  _globals['_AUDIORESAMPLERINFO']._serialized_end=3961
  _globals['_OWNEDAUDIORESAMPLER']._serialized_start=3963
  _globals['_OWNEDAUDIORESAMPLER']._serialized_end=4080
  _globals['_OWNEDAPM']._serialized_start=4082
  _globals['_OWNEDAPM']._serialized_end=4139
  _globals['_SOXRESAMPLERINFO']._serialized_start=4141
  _globals['_SOXRESAMPLERINFO']._serialized_end=4159
  _globals['_OWNEDSOXRESAMPLER']._serialized_start=4161
  _globals['_OWNEDSOXRESAMPLER']._serialized_end=4274
  _globals['_LOADAUDIOFILTERPLUGINREQUEST']._serialized_start=4276
  _globals['_LOADAUDIOFILTERPLUGINREQUEST']._serialized_end=4368
  _globals['_LOADAUDIOFILTERPLUGINRESPONSE']._serialized_start=4370
  _globals['_LOADAUDIOFILTERPLUGINRESPONSE']._serialized_end=4416
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video_frame.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import handle_pb2 as handle__pb2
from . import track_pb2 as track__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11video_frame.proto\x12\rlivekit.proto\x1a\x0chandle.proto\x1a\x0btrack.proto\"\xa5\x01\n\x15NewVideoStreamRequest\x12\x14\n\x0ctrack_handle\x18\x01 \x02(\x04\x12,\n\x04type\x18\x02 \x02(\x0e\x32\x1e.livekit.proto.VideoStreamType\x12.\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x1e.livekit.proto.VideoBufferType\x12\x18\n\x10normalize_stride\x18\x04 \x01(\x08\"I\n\x16NewVideoStreamResponse\x12/\n\x06stream\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedVideoStream\"\xe9\x01\n!VideoStreamFromParticipantRequest\x12\x1a\n\x12participant_handle\x18\x01 \x02(\x04\x12,\n\x04type\x18\x02 \x02(\x0e\x32\x1e.livekit.proto.VideoStreamType\x12\x30\n\x0ctrack_source\x18\x03 \x02(\x0e\x32\x1a.livekit.proto.TrackSource\x12.\n\x06\x66ormat\x18\x04 \x01(\x0e\x32\x1e.livekit.proto.VideoBufferType\x12\x18\n\x10normalize_stride\x18\x05 \x01(\x08\"U\n\"VideoStreamFromParticipantResponse\x12/\n\x06stream\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedVideoStream\"\x7f\n\x15NewVideoSourceRequest\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.VideoSourceType\x12\x38\n\nresolution\x18\x02 \x02(\x0b\x32$.livekit.proto.VideoSourceResolution\"I\n\x16NewVideoSourceResponse\x12/\n\x06source\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedVideoSource\"\xa7\x01\n\x18\x43\x61ptureVideoFrameRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x04\x12.\n\x06\x62uffer\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.VideoBufferInfo\x12\x14\n\x0ctimestamp_us\x18\x03 \x02(\x03\x12.\n\x08rotation\x18\x04 \x02(\x0e\x32\x1c.livekit.proto.VideoRotation\"\x1b\n\x19\x43\x61ptureVideoFrameResponse\"\x87\x01\n\x13VideoConvertRequest\x12\x0e\n\x06\x66lip_y\x18\x01 \x01(\x08\x12.\n\x06\x62uffer\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.VideoBufferInfo\x12\x30\n\x08\x64st_type\x18\x03 \x02(\x0e\x32\x1e.livekit.proto.VideoBufferType\"e\n\x14VideoConvertResponse\x12\x0f\n\x05\x65rror\x18\x01 \x01(\tH\x00\x12\x31\n\x06\x62uffer\x18\x02 \x01(\x0b\x32\x1f.livekit.proto.OwnedVideoBufferH\x00\x42\t\n\x07message\"D\n\x0fVideoResolution\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\x12\n\nframe_rate\x18\x03 \x02(\x01\"\x83\x02\n\x0fVideoBufferInfo\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.VideoBufferType\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\x10\n\x08\x64\x61ta_ptr\x18\x04 \x02(\x04\x12\x0e\n\x06stride\x18\x06 \x01(\r\x12@\n\ncomponents\x18\x07 \x03(\x0b\x32,.livekit.proto.VideoBufferInfo.ComponentInfo\x1a?\n\rComponentInfo\x12\x10\n\x08\x64\x61ta_ptr\x18\x01 \x02(\x04\x12\x0e\n\x06stride\x18\x02 \x02(\r\x12\x0c\n\x04size\x18\x03 \x02(\r\"o\n\x10OwnedVideoBuffer\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12,\n\x04info\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.VideoBufferInfo\"?\n\x0fVideoStreamInfo\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.VideoStreamType\"o\n\x10OwnedVideoStream\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12,\n\x04info\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.VideoStreamInfo\"\x9f\x01\n\x10VideoStreamEvent\x12\x15\n\rstream_handle\x18\x01 \x02(\x04\x12;\n\x0e\x66rame_received\x18\x02 \x01(\x0b\x32!.livekit.proto.VideoFrameReceivedH\x00\x12,\n\x03\x65os\x18\x03 \x01(\x0b\x32\x1d.livekit.proto.VideoStreamEOSH\x00\x42\t\n\x07message\"\x8b\x01\n\x12VideoFrameReceived\x12/\n\x06\x62uffer\x18\x01 \x02(\x0b\x32\x1f.livekit.proto.OwnedVideoBuffer\x12\x14\n\x0ctimestamp_us\x18\x02 \x02(\x03\x12.\n\x08rotation\x18\x03 \x02(\x0e\x32\x1c.livekit.proto.VideoRotation\"\x10\n\x0eVideoStreamEOS\"6\n\x15VideoSourceResolution\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\"?\n\x0fVideoSourceInfo\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.livekit.proto.VideoSourceType\"o\n\x10OwnedVideoSource\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12,\n\x04info\x18\x02 \x02(\x0b\x32\x1e.livekit.proto.VideoSourceInfo*;\n\nVideoCodec\x12\x07\n\x03VP8\x10\x00\x12\x08\n\x04H264\x10\x01\x12\x07\n\x03\x41V1\x10\x02\x12\x07\n\x03VP9\x10\x03\x12\x08\n\x04H265\x10\x04*l\n\rVideoRotation\x12\x14\n\x10VIDEO_ROTATION_0\x10\x00\x12\x15\n\x11VIDEO_ROTATION_90\x10\x01\x12\x16\n\x12VIDEO_ROTATION_180\x10\x02\x12\x16\n\x12VIDEO_ROTATION_270\x10\x03*\x81\x01\n\x0fVideoBufferType\x12\x08\n\x04RGBA\x10\x00\x12\x08\n\x04\x41\x42GR\x10\x01\x12\x08\n\x04\x41RGB\x10\x02\x12\x08\n\x04\x42GRA\x10\x03\x12\t\n\x05RGB24\x10\x04\x12\x08\n\x04I420\x10\x05\x12\t\n\x05I420A\x10\x06\x12\x08\n\x04I422\x10\x07\x12\x08\n\x04I444\x10\x08\x12\x08\n\x04I010\x10\t\x12\x08\n\x04NV12\x10\n*Y\n\x0fVideoStreamType\x12\x17\n\x13VIDEO_STREAM_NATIVE\x10\x00\x12\x16\n\x12VIDEO_STREAM_WEBGL\x10\x01\x12\x15\n\x11VIDEO_STREAM_HTML\x10\x02**\n\x0fVideoSourceType\x12\x17\n\x13VIDEO_SOURCE_NATIVE\x10\x00\x42\x10\xaa\x02\rLiveKit.Proto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video_frame_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\rLiveKit.Proto'
  _globals['_VIDEOCODEC']._serialized_start=2452
  _globals['_VIDEOCODEC']._serialized_end=2511
  _globals['_VIDEOROTATION']._serialized_start=2513
  _globals['_VIDEOROTATION']._serialized_end=2621
  _globals['_VIDEOBUFFERTYPE']._serialized_start=2624
  _globals['_VIDEOBUFFERTYPE']._serialized_end=2753
  _globals['_VIDEOSTREAMTYPE']._serialized_start=2755
  _globals['_VIDEOSTREAMTYPE']._serialized_end=2844
  _globals['_VIDEOSOURCETYPE']._serialized_start=2846
  _globals['_VIDEOSOURCETYPE']._serialized_end=2888
  _globals['_NEWVIDEOSTREAMREQUEST']._serialized_start=64
  _globals['_NEWVIDEOSTREAMREQUEST']._serialized_end=229
  _globals['_NEWVIDEOSTREAMRESPONSE']._serialized_start=231
  _globals['_NEWVIDEOSTREAMRESPONSE']._serialized_end=304
  _globals['_VIDEOSTREAMFROMPARTICIPANTREQUEST']._serialized_start=307
  _globals['_VIDEOSTREAMFROMPARTICIPANTREQUEST']._serialized_end=540
  _globals['_VIDEOSTREAMFROMPARTICIPANTRESPONSE']._serialized_start=542
  _globals['_VIDEOSTREAMFROMPARTICIPANTRESPONSE']._serialized_end=627
  _globals['_NEWVIDEOSOURCEREQUEST']._serialized_start=629
  _globals['_NEWVIDEOSOURCEREQUEST']._serialized_end=756
  _globals['_NEWVIDEOSOURCERESPONSE']._serialized_start=758
  _globals['_NEWVIDEOSOURCERESPONSE']._serialized_end=831
  _globals['_CAPTUREVIDEOFRAMEREQUEST']._serialized_start=834
  _globals['_CAPTUREVIDEOFRAMEREQUEST']._serialized_end=1001
  _globals['_CAPTUREVIDEOFRAMERESPONSE']._serialized_start=1003
  _globals['_CAPTUREVIDEOFRAMERESPONSE']._serialized_end=1030
  _globals['_VIDEOCONVERTREQUEST']._serialized_start=1033
  _globals['_VIDEOCONVERTREQUEST']._serialized_end=1168
  _globals['_VIDEOCONVERTRESPONSE']._serialized_start=1170
  _globals['_VIDEOCONVERTRESPONSE']._serialized_end=1271
  _globals['_VIDEORESOLUTION']._serialized_start=1273
  _globals['_VIDEORESOLUTION']._serialized_end=1341
  _globals['_VIDEOBUFFERINFO']._serialized_start=1344
  _globals['_VIDEOBUFFERINFO']._serialized_end=1603
  _globals['_VIDEOBUFFERINFO_COMPONENTINFO']._serialized_start=1540
  _globals['_VIDEOBUFFERINFO_COMPONENTINFO']._serialized_end=1603
  _globals['_OWNEDVIDEOBUFFER']._serialized_start=1605
  _globals['_OWNEDVIDEOBUFFER']._serialized_end=1716
  _globals['_VIDEOSTREAMINFO']._serialized_start=1718
  _globals['_VIDEOSTREAMINFO']._serialized_end=1781
  _globals['_OWNEDVIDEOSTREAM']._serialized_start=1783
  _globals['_OWNEDVIDEOSTREAM']._serialized_end=1894
  _globals['_VIDEOSTREAMEVENT']._serialized_start=1897
  _globals['_VIDEOSTREAMEVENT']._serialized_end=2056
  _globals['_VIDEOFRAMERECEIVED']._serialized_start=2059
  _globals['_VIDEOFRAMERECEIVED']._serialized_end=2198
  _globals['_VIDEOSTREAMEOS']._serialized_start=2200
  _globals['_VIDEOSTREAMEOS']._serialized_end=2216
  _globals['_VIDEOSOURCERESOLUTION']._serialized_start=2218
  _globals['_VIDEOSOURCERESOLUTION']._serialized_end=2272
  _globals['_VIDEOSOURCEINFO']._serialized_start=2274
  _globals['_VIDEOSOURCEINFO']._serialized_end=2337
  _globals['_OWNEDVIDEOSOURCE']._serialized_start=2339
  _globals['_OWNEDVIDEOSOURCE']._serialized_end=2450
# @@protoc_insertion_point(module_scope)



from typing import List
from dataclasses import dataclass


@dataclass
class Transcription:
    participant_identity: str
    track_sid: str
    segments: List["TranscriptionSegment"]


@dataclass
class TranscriptionSegment:
    id: str
    text: str
    start_time: int
    end_time: int
    language: str
    final: bool



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: track.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import e2ee_pb2 as e2ee__pb2
from . import handle_pb2 as handle__pb2
from . import stats_pb2 as stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btrack.proto\x12\rlivekit.proto\x1a\ne2ee.proto\x1a\x0chandle.proto\x1a\x0bstats.proto\">\n\x17\x43reateVideoTrackRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x15\n\rsource_handle\x18\x02 \x02(\x04\"D\n\x18\x43reateVideoTrackResponse\x12(\n\x05track\x18\x01 \x02(\x0b\x32\x19.livekit.proto.OwnedTrack\">\n\x17\x43reateAudioTrackRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x15\n\rsource_handle\x18\x02 \x02(\x04\"D\n\x18\x43reateAudioTrackResponse\x12(\n\x05track\x18\x01 \x02(\x0b\x32\x19.livekit.proto.OwnedTrack\"\'\n\x0fGetStatsRequest\x12\x14\n\x0ctrack_handle\x18\x01 \x02(\x04\"$\n\x10GetStatsResponse\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\"[\n\x10GetStatsCallback\x12\x10\n\x08\x61sync_id\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12&\n\x05stats\x18\x03 \x03(\x0b\x32\x17.livekit.proto.RtcStats\"\x0c\n\nTrackEvent\"\xdd\x02\n\x14TrackPublicationInfo\x12\x0b\n\x03sid\x18\x01 \x02(\t\x12\x0c\n\x04name\x18\x02 \x02(\t\x12&\n\x04kind\x18\x03 \x02(\x0e\x32\x18.livekit.proto.TrackKind\x12*\n\x06source\x18\x04 \x02(\x0e\x32\x1a.livekit.proto.TrackSource\x12\x13\n\x0bsimulcasted\x18\x05 \x02(\x08\x12\r\n\x05width\x18\x06 \x02(\r\x12\x0e\n\x06height\x18\x07 \x02(\r\x12\x11\n\tmime_type\x18\x08 \x02(\t\x12\r\n\x05muted\x18\t \x02(\x08\x12\x0e\n\x06remote\x18\n \x02(\x08\x12\x36\n\x0f\x65ncryption_type\x18\x0b \x02(\x0e\x32\x1d.livekit.proto.EncryptionType\x12\x38\n\x0e\x61udio_features\x18\x0c \x03(\x0e\x32 .livekit.proto.AudioTrackFeature\"y\n\x15OwnedTrackPublication\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12\x31\n\x04info\x18\x02 \x02(\x0b\x32#.livekit.proto.TrackPublicationInfo\"\x9f\x01\n\tTrackInfo\x12\x0b\n\x03sid\x18\x01 \x02(\t\x12\x0c\n\x04name\x18\x02 \x02(\t\x12&\n\x04kind\x18\x03 \x02(\x0e\x32\x18.livekit.proto.TrackKind\x12\x30\n\x0cstream_state\x18\x04 \x02(\x0e\x32\x1a.livekit.proto.StreamState\x12\r\n\x05muted\x18\x05 \x02(\x08\x12\x0e\n\x06remote\x18\x06 \x02(\x08\"c\n\nOwnedTrack\x12-\n\x06handle\x18\x01 \x02(\x0b\x32\x1d.livekit.proto.FfiOwnedHandle\x12&\n\x04info\x18\x02 \x02(\x0b\x32\x18.livekit.proto.TrackInfo\";\n\x15LocalTrackMuteRequest\x12\x14\n\x0ctrack_handle\x18\x01 \x02(\x04\x12\x0c\n\x04mute\x18\x02 \x02(\x08\"\'\n\x16LocalTrackMuteResponse\x12\r\n\x05muted\x18\x01 \x02(\x08\"A\n\x18\x45nableRemoteTrackRequest\x12\x14\n\x0ctrack_handle\x18\x01 \x02(\x04\x12\x0f\n\x07\x65nabled\x18\x02 \x02(\x08\",\n\x19\x45nableRemoteTrackResponse\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"\xac\x01\n&SetTrackSubscriptionPermissionsRequest\x12 \n\x18local_participant_handle\x18\x01 \x02(\x04\x12 \n\x18\x61ll_participants_allowed\x18\x02 \x02(\x08\x12>\n\x0bpermissions\x18\x03 \x03(\x0b\x32).livekit.proto.ParticipantTrackPermission\"i\n\x1aParticipantTrackPermission\x12\x1c\n\x14participant_identity\x18\x01 \x02(\t\x12\x11\n\tallow_all\x18\x02 \x01(\x08\x12\x1a\n\x12\x61llowed_track_sids\x18\x03 \x03(\t\")\n\'SetTrackSubscriptionPermissionsResponse*=\n\tTrackKind\x12\x10\n\x0cKIND_UNKNOWN\x10\x00\x12\x0e\n\nKIND_AUDIO\x10\x01\x12\x0e\n\nKIND_VIDEO\x10\x02*\x81\x01\n\x0bTrackSource\x12\x12\n\x0eSOURCE_UNKNOWN\x10\x00\x12\x11\n\rSOURCE_CAMERA\x10\x01\x12\x15\n\x11SOURCE_MICROPHONE\x10\x02\x12\x16\n\x12SOURCE_SCREENSHARE\x10\x03\x12\x1c\n\x18SOURCE_SCREENSHARE_AUDIO\x10\x04*D\n\x0bStreamState\x12\x11\n\rSTATE_UNKNOWN\x10\x00\x12\x10\n\x0cSTATE_ACTIVE\x10\x01\x12\x10\n\x0cSTATE_PAUSED\x10\x02*\xbd\x01\n\x11\x41udioTrackFeature\x12\r\n\tTF_STEREO\x10\x00\x12\r\n\tTF_NO_DTX\x10\x01\x12\x18\n\x14TF_AUTO_GAIN_CONTROL\x10\x02\x12\x18\n\x14TF_ECHO_CANCELLATION\x10\x03\x12\x18\n\x14TF_NOISE_SUPPRESSION\x10\x04\x12\"\n\x1eTF_ENHANCED_NOISE_CANCELLATION\x10\x05\x12\x18\n\x14TF_PRECONNECT_BUFFER\x10\x06\x42\x10\xaa\x02\rLiveKit.Proto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'track_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\rLiveKit.Proto'
  _globals['_TRACKKIND']._serialized_start=1801
  _globals['_TRACKKIND']._serialized_end=1862
  _globals['_TRACKSOURCE']._serialized_start=1865
  _globals['_TRACKSOURCE']._serialized_end=1994
  _globals['_STREAMSTATE']._serialized_start=1996
  _globals['_STREAMSTATE']._serialized_end=2064
  _globals['_AUDIOTRACKFEATURE']._serialized_start=2067
  _globals['_AUDIOTRACKFEATURE']._serialized_end=2256
  _globals['_CREATEVIDEOTRACKREQUEST']._serialized_start=69
  _globals['_CREATEVIDEOTRACKREQUEST']._serialized_end=131
  _globals['_CREATEVIDEOTRACKRESPONSE']._serialized_start=133
  _globals['_CREATEVIDEOTRACKRESPONSE']._serialized_end=201
  _globals['_CREATEAUDIOTRACKREQUEST']._serialized_start=203
  _globals['_CREATEAUDIOTRACKREQUEST']._serialized_end=265
  _globals['_CREATEAUDIOTRACKRESPONSE']._serialized_start=267
  _globals['_CREATEAUDIOTRACKRESPONSE']._serialized_end=335
  _globals['_GETSTATSREQUEST']._serialized_start=337
  _globals['_GETSTATSREQUEST']._serialized_end=376
  _globals['_GETSTATSRESPONSE']._serialized_start=378
  _globals['_GETSTATSRESPONSE']._serialized_end=414
  _globals['_GETSTATSCALLBACK']._serialized_start=416
  _globals['_GETSTATSCALLBACK']._serialized_end=507
  _globals['_TRACKEVENT']._serialized_start=509
  _globals['_TRACKEVENT']._serialized_end=521
  _globals['_TRACKPUBLICATIONINFO']._serialized_start=524
  _globals['_TRACKPUBLICATIONINFO']._serialized_end=873
  _globals['_OWNEDTRACKPUBLICATION']._serialized_start=875
  _globals['_OWNEDTRACKPUBLICATION']._serialized_end=996
  _globals['_TRACKINFO']._serialized_start=999
  _globals['_TRACKINFO']._serialized_end=1158
  _globals['_OWNEDTRACK']._serialized_start=1160
  _globals['_OWNEDTRACK']._serialized_end=1259
  _globals['_LOCALTRACKMUTEREQUEST']._serialized_start=1261
  _globals['_LOCALTRACKMUTEREQUEST']._serialized_end=1320
  _globals['_LOCALTRACKMUTERESPONSE']._serialized_start=1322
  _globals['_LOCALTRACKMUTERESPONSE']._serialized_end=1361
  _globals['_ENABLEREMOTETRACKREQUEST']._serialized_start=1363
  _globals['_ENABLEREMOTETRACKREQUEST']._serialized_end=1428
  _globals['_ENABLEREMOTETRACKRESPONSE']._serialized_start=1430
  _globals['_ENABLEREMOTETRACKRESPONSE']._serialized_end=1474
  _globals['_SETTRACKSUBSCRIPTIONPERMISSIONSREQUEST']._serialized_start=1477
  _globals['_SETTRACKSUBSCRIPTIONPERMISSIONSREQUEST']._serialized_end=1649
  _globals['_PARTICIPANTTRACKPERMISSION']._serialized_start=1651
  _globals['_PARTICIPANTTRACKPERMISSION']._serialized_end=1756
  _globals['_SETTRACKSUBSCRIPTIONPERMISSIONSRESPONSE']._serialized_start=1758
  _globals['_SETTRACKSUBSCRIPTIONPERMISSIONSRESPONSE']._serialized_end=1799
# @@protoc_insertion_point(module_scope)
